/*****************************************************************************************/
/*											 */	
/* Description : TMS320F240 Header file with all Peripheral Register declarations	 */	
/*		 plus other useful defines.						 */	
/*											 */	
/*****************************************************************************************/


#ifndef		__REGISTER_H
#define		__REGISTER_H


/*--------------------------------------------------------------*/
/* On Chip Periperal Register Definitions (DATA SPACE)		*/
/*--------------------------------------------------------------*/

/* C2xx Core Registers */

#define		IMR		(int *)0x0004			/* Int Mask Register */
#define 	GREG		(int *)0x0005			/* Global memory allocation reg */
#define		IFR		(int *)0x0006			/* Int Flag Register */
#define		ABRPT		(int *)0x001F			/* Analysis BreakPoint Register */

/* System Module Registers */

#define		SYSCR		(int *)0x7018			/* System Module Control Register */
#define		SYSSR		(int *)0x701A			/* System Module Status Register */
#define		DIN		(int *)0x701C			/* Device Identification Register */
#define		SYSIVR		(int *)0x701E			/* System Interrupt Vector Register */ 
#define		XINT1_CNTL	(int *)0x7070			/* Int1 (type A) Control reg */
#define		NMI_CNTL	(int *)0x7072			/* Non maskable Int (type A) Control reg */
#define		XINT2_CNTL	(int *)0x7078			/* Int2 (type C) Control reg */
#define		XINT3_CNTL	(int *)0x707A			/* Int3 (type C) Control reg */
#define		PDPINT_CNTL	(int *)0x742C		/* Power Drive Protection Int cntl reg */


/* Digital I/O */

#define		OPCRA		(int *)0x7090			/* Output Control Reg A */
#define		OPCRB		(int *)0x7092			/* Output Control Reg B */
#define		IPSRA		(int *)0x7094			/* Input Status Reg A */
#define		IPSRB		(int *)0x7096			/* Input Status Reg B */
#define		PADATDIR	(int *)0x7098			/* I/O port A Data & Direction reg. */
#define		PBDATDIR	(int *)0x709A			/* I/O port B Data & Direction reg. */
#define		PCDATDIR	(int *)0x709C			/* I/O port C Data & Direction reg. */
#define		PDDATDIR	(int *)0x709E			/* I/O port D Data & Direction reg. */

/* Watch-Dog(WD) / Real Time Int(RTI) / Phase Lock Loop(PLL) Registers */

#define		RTI_CNTR	(int *)0x7021			/* RTI Counter reg */
#define		WD_CNTR 	(int *)0x7023			/* WD Counter reg */
#define		WD_KEY		(int *)0x7025			/* WD Key reg */
#define		RTI_CNTL	(int *)0x7027			/* RTI Control reg */
#define		WD_CNTL 	(int *)0x7029			/* WD Control reg */
#define		PLL_CNTL1	(int *)0x702B			/* PLL control reg 1 */
#define		PLL_CNTL2	(int *)0x702D			/* PLL control reg 2 */
#define		CKCR0		(int *)0x702B
#define		CKCR1		(int *)0x702D

	

/* Analog-to-Digital Converter(ADC) registers */

#define		ADC_CNTL1		(int *)0x7032			/* ADC Control reg 1 */
#define		ADC_CNTL2		(int *)0x7034			/* ADC Control reg 2 */
#define		ADC_FIFO1		(int *)0x7036		/* ADC FIFO data reg 1 */
#define		ADC_FIFO2		(int *)0x7038			/* ADC FIFO data reg 2 */


/* Serial Peripheral Interface (SPI) Registers */

#define		SPI_CCR 		(int *)0x7040			/* SPI Config Control Reg 1 */
#define		SPI_CTL 		(int *)0x7041			/* SPI Operation Control Reg 2 */
#define		SPI_STS 		(int *)0x7042			/* SPI Status Reg */
#define		SPI_BRR 		(int *)0x7044			/* SPI Baud rate control reg */
#define		SPI_EMU 		(int *)0x7046			/* SPI Emulation buffer reg */
#define		SPI_BUF 		(int *)0x7047			/* SPI Serial Input buffer reg */
#define		SPI_DAT 		(int *)0x7049			/* SPI Serial Data reg */
#define		SPI_PC1 		(int *)0x704D			/* SPI Port control reg1 */
#define		SPI_PC2 		(int *)0x704E			/* SPI Port control reg2 */
#define		SPI_PRI 		(int *)0x704F			/* SPI Priority control reg */


/* Serial Communications Interface (SCI) Registers */

#define		SCI_CCNTL		(int *)0x7050			/* SCI Comms Control Reg */
#define		SCI_CNTL1		(int *)0x7051			/* SCI Baud rate control */
#define		SCI_LBAUD		(int *)0x7053			/* SCI Control Reg 1 */
#define		SCI_HBAUD		(int *)0x7052			/* SCI Baud rate control */
#define		SCI_CNTL2		(int *)0x7054			/* SCI Control Reg 2 */
#define		SCI_RX_STAT	(int *)0x7055			/* SCI Receive status reg */
#define		SCI_RX_EMU		(int *)0x7056			/* SCI EMU data buffer */
#define		SCI_RX_BUF		(int *)0x7057			/* SCI Receive data buffer */
#define		SCI_TX_BUF		(int *)0x7059			/* SCI Transmit data buffer */
#define		SCI_PORT_C1	(int *)0x705D			/* SCI Port control reg1 */
#define		SCI_PORT_C2	(int *)0x705E			/* SCI Port control reg2 */
#define		SCI_PRI 		(int *)0x705F			/* SCI Priority control reg */


/* Event Manager (EV) - EV Base Address = 0x7400 */


#define		GPTCON	   	(int *)0x7400  		/* General Timer Controls */
#define		T1CNT	   	(int *)0x7401  		/* T1 Counter Register */
#define		T1CMP	   	(int *)0x7402  		/* T1 Compare Register */
#define		T1PER	   	(int *)0x7403   		/* T1 Period Register */
#define		T1CON	   	(int *)0x7404   		/* T1 Control Register */
#define		T2CNT	   	(int *)0x7405  		/* T2 Counter Register */
#define		T2CMP	   	(int *)0x7406   		/* T2 Compare Register */
#define		T2PER	   	(int *)0x7407   		/* T2 Period Register */
#define		T2CON	   	(int *)0x7408   		/* T2 Control Register */
#define		T3CNT	   	(int *)0x7409   		/* T3 Counter Register */
#define		T3CMP	   	(int *)0x740A   		/* T3 Compare Register */
#define		T3PER	   	(int *)0x740B   		/* T3 Period Register */
#define		T3CON	   	(int *)0x740C   		/* T3 Control Register */
#define		COMCON	   	(int *)0x7411   		/* Compare Unit Control */
#define		ACTR	   	(int *)0x7413   		/* Compare Unit Output Action Control */
#define		SACTR	   	(int *)0x7414   		/* S Comp Unit Output Action Control */
#define		DBTCON	   	(int *)0x7415   		/* Dead Band Timer Control */
#define		CMPR1	   	(int *)0x7417   		/* Compare Channel 1 Threshold */
#define		CMPR2	   	(int *)0x7418  		/* Compare Channel 2 Threshold */
#define		CMPR3	   	(int *)0x7419   		/* Compare Channel 3 Threshold */
#define		SCMPR1	   	(int *)0x741A  		/* S Comp Channel 1 Threshold */
#define		SCMPR2	   	(int *)0x741B  		/* S Comp Channel 2 Threshold */
#define		SCMPR3	   	(int *)0x741C   		/* S Comp Channel 3 Threshold */
#define		CAPCON	   	(int *)0x7420   		/* Capture Unit Control */
#define		CAPFIFO    	(int *)0x7422   		/* FIFO1-4 Status Register */
#define		FIFO1	   	(int *)0x7423   		/* Capture Channel 1 FIFO Top */
#define		FIFO2	   	(int *)0x7424  		/* Capture Channel 2 FIFO Top */
#define		FIFO3	   	(int *)0x7425   		/* Capture Channel 3 FIFO Top */
#define		FIFO4	   	(int *)0x7426   		/* Capture Channel 4 FIFO Top */
#define		IMRA	   	(int *)0x742C   		/* Group A Interrupt Mask Register */
#define		IMRB	   	(int *)0x742D   		/* Group B Interrupt Mask Register */
#define		IMRC	   	(int *)0x742E   		/* Group C Interrupt Mask Register */
#define		IFRA	   	(int *)0x742F   		/* Group A Interrupt Flag Register */
#define		IFRB	   	(int *)0x7430  		/* Group B Interrupt Flag Register */
#define		IFRC	   	(int *)0x7431   		/* Group C Interrupt Flag Register */
#define		IVRA	   	(int *)0x7432   		/* Group A Int. Vector Offset(AD dec only) */
#define		IVRB	   	(int *)0x7433   		/* Group B Int. Vector Offset(AD dec only) */
#define		IVRC	   	(int *)0x7434  		/* Group C Int. Vector Offset(AD dec only) */

#endif