
/*****************************************************************************************/
/*											 */	
/* Description : TMS320F240 Header file with all Peripheral Register declarations	 */	
/*		 plus other useful defines.						 */	
/*											 */	
/*****************************************************************************************/


#ifndef		__REGISTER_H
#define		__REGISTER_H


/*--------------------------------------------------------------*/
/* On Chip Periperal Register Definitions (DATA SPACE)		*/
/*--------------------------------------------------------------*/

/* C2xx Core Registers */

#define		ADDR_IMR		0x0004U			/* Int Mask Register */
#define 	ADDR_GREG		0x0005U			/* Global memory allocation reg */
#define		ADDR_IFR		0x0006U			/* Int Flag Register */
#define		ADDR_ABRPT		0x001FU			/* Analysis BreakPoint Register */

/* System Module Registers */

#define		ADDR_SYSCR		0x7018U			/* System Module Control Register */
#define		ADDR_SYSSR		0x701AU			/* System Module Status Register */
#define		ADDR_DIN		0x701CU			/* Device Identification Register */
#define		ADDR_SYSIVR		0x701EU			/* System Interrupt Vector Register */ 
#define		ADDR_XINT1_CNTL		0x7070U			/* Int1 (type A) Control reg */
#define		ADDR_NMI_CNTL		0x7072U			/* Non maskable Int (type A) Control reg */
#define		ADDR_XINT2_CNTL		0x7078U			/* Int2 (type C) Control reg */
#define		ADDR_XINT3_CNTL		0x707AU			/* Int3 (type C) Control reg */
#define		ADDR_PDPINT_CNTL	0x742CU			/* Power Drive Protection Int cntl reg */


/* Digital I/O */

#define		ADDR_OPCRA		0x7090U			/* Output Control Reg A */
#define		ADDR_OPCRB		0x7092U			/* Output Control Reg B */
#define		ADDR_IPSRA		0x7094U			/* Input Status Reg A */
#define		ADDR_IPSRB		0x7096U			/* Input Status Reg B */
#define		ADDR_PADATDIR		0x7098U			/* I/O port A Data & Direction reg. */
#define		ADDR_PBDATDIR		0x709AU			/* I/O port B Data & Direction reg. */
#define		ADDR_PCDATDIR		0x709CU			/* I/O port C Data & Direction reg. */
#define		ADDR_PDDATDIR		0x709EU			/* I/O port D Data & Direction reg. */


/* Watch-Dog(WD) / Real Time Int(RTI) / Phase Lock Loop(PLL) Registers */

#define		ADDR_RTI_CNTR		0x7021U			/* RTI Counter reg */
#define		ADDR_WD_CNTR 		0x7023U			/* WD Counter reg */
#define		ADDR_WD_KEY		0x7025U			/* WD Key reg */
#define		ADDR_RTI_CNTL		0x7027U			/* RTI Control reg */
#define		ADDR_WD_CNTL 		0x7029U			/* WD Control reg */
#define		ADDR_PLL_CNTL1		0x702BU			/* PLL control reg 1 */
#define		ADDR_PLL_CNTL2		0x702DU			/* PLL control reg 2 */
	

/* Analog-to-Digital Converter(ADC) registers */

#define		ADDR_ADC_CNTL1		0x7032U			/* ADC Control reg 1 */
#define		ADDR_ADC_CNTL2		0x7034U			/* ADC Control reg 2 */
#define		ADDR_ADC_FIFO1		0x7036U			/* ADC FIFO data reg 1 */
#define		ADDR_ADC_FIFO2		0x7038U			/* ADC FIFO data reg 2 */


/* Serial Peripheral Interface (SPI) Registers */

#define		ADDR_SPI_CCR 		0x7040U			/* SPI Config Control Reg 1 */
#define		ADDR_SPI_CTL 		0x7041U			/* SPI Operation Control Reg 2 */
#define		ADDR_SPI_STS 		0x7042U			/* SPI Status Reg */
#define		ADDR_SPI_BRR 		0x7044U			/* SPI Baud rate control reg */
#define		ADDR_SPI_EMU 		0x7046U			/* SPI Emulation buffer reg */
#define		ADDR_SPI_BUF 		0x7047U			/* SPI Serial Input buffer reg */
#define		ADDR_SPI_DAT 		0x7049U			/* SPI Serial Data reg */
#define		ADDR_SPI_PC1 		0x704DU			/* SPI Port control reg1 */
#define		ADDR_SPI_PC2 		0x704EU			/* SPI Port control reg2 */
#define		ADDR_SPI_PRI 		0x704FU			/* SPI Priority control reg */


/* Serial Communications Interface (SCI) Registers */

#define		ADDR_SCI_CCNTL		0x7050U			/* SCI Comms Control Reg */
#define		ADDR_SCI_CNTL1		0x7051U			/* SCI Baud rate control */
#define		ADDR_SCI_LBAUD		0x7053U			/* SCI Control Reg 1 */
#define		ADDR_SCI_HBAUD		0x7052U			/* SCI Baud rate control */
#define		ADDR_SCI_CNTL2		0x7054U			/* SCI Control Reg 2 */
#define		ADDR_SCI_RX_STAT	0x7055U			/* SCI Receive status reg */
#define		ADDR_SCI_RX_EMU		0x7056U			/* SCI EMU data buffer */
#define		ADDR_SCI_RX_BUF		0x7057U			/* SCI Receive data buffer */
#define		ADDR_SCI_TX_BUF		0x7059U			/* SCI Transmit data buffer */
#define		ADDR_SCI_PORT_C1	0x705DU			/* SCI Port control reg1 */
#define		ADDR_SCI_PORT_C2	0x705EU			/* SCI Port control reg2 */
#define		ADDR_SCI_PRI 		0x705FU			/* SCI Priority control reg */


/* Event Manager (EV) - EV Base Address = 0x7400 */


#define		ADDR_GPTCON	   	0x7400U  		/* General Timer Controls */
#define		ADDR_T1CNT	   	0x7401U  		/* T1 Counter Register */
#define		ADDR_T1CMP	   	0x7402U  		/* T1 Compare Register */
#define		ADDR_T1PER	   	0x7403U   		/* T1 Period Register */
#define		ADDR_T1CON	   	0x7404U   		/* T1 Control Register */
#define		ADDR_T2CNT	   	0x7405U  		/* T2 Counter Register */
#define		ADDR_T2CMP	   	0x7406U   		/* T2 Compare Register */
#define		ADDR_T2PER	   	0x7407U   		/* T2 Period Register */
#define		ADDR_T2CON	   	0x7408U   		/* T2 Control Register */
#define		ADDR_T3CNT	   	0x7409U   		/* T3 Counter Register */
#define		ADDR_T3CMP	   	0x740AU   		/* T3 Compare Register */
#define		ADDR_T3PER	   	0x740BU   		/* T3 Period Register */
#define		ADDR_T3CON	   	0x740CU   		/* T3 Control Register */
#define		ADDR_COMCON	   	0x7411U   		/* Compare Unit Control */
#define		ADDR_ACTR	   	0x7413U   		/* Compare Unit Output Action Control */
#define		ADDR_SACTR	   	0x7414U   		/* S Comp Unit Output Action Control */
#define		ADDR_DBTCON	   	0x7415U   		/* Dead Band Timer Control */
#define		ADDR_CMPR1	   	0x7417U   		/* Compare Channel 1 Threshold */
#define		ADDR_CMPR2	   	0x7418U  		/* Compare Channel 2 Threshold */
#define		ADDR_CMPR3	   	0x7419U   		/* Compare Channel 3 Threshold */
#define		ADDR_SCMPR1	   	0x741AU  		/* S Comp Channel 1 Threshold */
#define		ADDR_SCMPR2	   	0x741BU  		/* S Comp Channel 2 Threshold */
#define		ADDR_SCMPR3	   	0x741CU   		/* S Comp Channel 3 Threshold */
#define		ADDR_CAPCON	   	0x7420U   		/* Capture Unit Control */
#define		ADDR_CAPFIFO    	0x7422U   		/* FIFO1-4 Status Register */
#define		ADDR_FIFO1	   	0x7423U   		/* Capture Channel 1 FIFO Top */
#define		ADDR_FIFO2	   	0x7424U  		/* Capture Channel 2 FIFO Top */
#define		ADDR_FIFO3	   	0x7425U   		/* Capture Channel 3 FIFO Top */
#define		ADDR_FIFO4	   	0x7426U   		/* Capture Channel 4 FIFO Top */
#define		ADDR_IMRA	   	0x742CU   		/* Group A Interrupt Mask Register */
#define		ADDR_IMRB	   	0x742DU   		/* Group B Interrupt Mask Register */
#define		ADDR_IMRC	   	0x742EU   		/* Group C Interrupt Mask Register */
#define		ADDR_IFRA	   	0x742FU   		/* Group A Interrupt Flag Register */
#define		ADDR_IFRB	   	0x7430U  		/* Group B Interrupt Flag Register */
#define		ADDR_IFRC	   	0x7431U   		/* Group C Interrupt Flag Register */
#define		ADDR_IVRA	   	0x7432U   		/* Group A Int. Vector Offset(AD dec only) */
#define		ADDR_IVRB	   	0x7433U   		/* Group B Int. Vector Offset(AD dec only) */
#define		ADDR_IVRC	   	0x7434U  		/* Group C Int. Vector Offset(AD dec only) */

#endif