/****************************************************************************
 **                                                                        **
 **                    # DSP TMS320F240 PLUS Header File #                 **
 **                                                                        **
 ** .     DSP TMS320F240 ̴ Ϳ   **
 **     Դϴ.      ִ ϱ   **
 **      Ͽϴ.                                       **
 **                                                                        **
 ** .       뵵ε  մϴ.        **
 **                                                                        **
 **                                       - E.S.Lab., National Mokpo Univ. **
 **                                           - Homepage : www.eslab.or.kr **
 **                                                                        **
 **                                    - Last Updated : 2002.04.10, By Sun **
 ****************************************************************************/


#ifndef __REGISTER_H
#include "240.h"		/* TMS320F240 ⺻   ÷ */
#endif

#ifndef ESLAB240_HEADER_INCLUDED
#define ESLAB240_HEADER_INCLUDED


/*                      ## Common Control Function ##                       */
/*                                                                          */
/* . ENABLE_GLOBAL_INT() - ü ͷƮ Enable Ų.                   */
/*                       - return : none                                    */
/*                                                                          */
/* . DISABLE_GLOBAL_INT() - ü ͷƮ Disable Ų.                 */
/*                        - return : none                                   */
/*                                                                          */
/* . DISABLE_WDT() - Watch Dog Timer Disable Ų.                      */
/*                 - return : none                                          */
/*                                                                          */
/* . SET_XF() - XF  Set Ų.                                         */
/*            - return : none                                               */
/*                                                                          */
/* . CLEAR_XF() - XF  Clear Ų.                                     */
/*              - return : none                                             */

#define ENABLE_ALL_INT()            asm("	CLRC	INTM")
#define DISABLE_ALL_INT()           asm("	SETC	INTM")

#define DISABLE_WDT()               ((*WD_CNTL) = (0x6f))

#define SET_XF()                    asm("	SETC	XF")
#define CLEAR_XF()                  asm("	CLRC	XF")


/*             ## I/O MUX Control Register A (OPCRA-7090h) ##               */
/*                                                                          */
/* Note : ADCIN, PWM_CMP, GP_TIMER_PWM_CMP, TMRDIR, TMRCLK                  */

#define OPCRA_ADCIN_0			0x0001		/* default - IOPA0 */
#define OPCRA_ADCIN_1			0x0002		/* default - IOPA1 */
#define OPCRA_ADCIN_9			0X0004		/* default - IOPA2 */
#define OPCRA_ADCIN_8			0x0008		/* default - IOPA3 */

#define OPCRA_PWM_CMP_7			0x0100		/* default - IOPB0 */
#define OPCRA_PWM_CMP_8			0x0200		/* default - IOPB1 */
#define OPCRA_PWM_CMP_9			0x0400		/* default - IOPB2 */

#define OPCRA_T1_PWM_CMP		0x0800		/* default - IOPB3 */
#define OPCRA_T2_PWM_CMP		0x1000		/* default - IOPB4 */
#define OPCRA_T3_PWM_CMP		0x2000		/* default - IOPB5 */

#define OPCRA_TMRDIR			0x4000		/* default - IOPB6 */
#define OPCRA_TMRCLK			0x8000		/* default - IOPB7 */


/*             ## I/O MUX Control Register B (OPCRB-7092h) ##               */
/*                                                                          */
/* Note : ADCSOC, IOPC, CAP_QEP, CAPTURE                                    */

#define OPCRB_ADCSOC            0x01		/* default - IOPC0	*/

#define OPCRB_IOPC2             0x04		/* default - XF		*/
#define OPCRB_IOPC3             0x08		/* default - BIO	*/

#define OPCRB_CAP_QEP_1         0x10		/* default - IOPC4	*/
#define OPCRB_CAP_QEP_2         0x20		/* default - IOPC5	*/

#define OPCRB_CAP_3             0x40		/* default - IOPC6	*/
#define OPCRB_CAP_4             0x80		/* default - IOPC7	*/


/*             ## GP Timer Control Register (GPTCON-7400h) ##               */
/*                                                                          */

/*                        ## Clock Control Function ##                      */
/*                                                                          */
/* . IS_PLL_LOCKED() - PLL Module ο  ѵ    */
/*                    ýۿ  Ǿ ˾Ƴ Լ̴.             */
/*                   - return : 0 (  ʾҴ.)                   */
/*                              > 0 ( Ǿ.)                          */

#define IS_PLL_LOCKED()				((*CKCR0) & (PLLOCK_LOCKED))


/*              ## Clock Control Register 0 (CKCR0-702Bh) ##                */
/*                                                                          */
/*     7        6        5         4         3        2         1      0    */
/*  CLKMD(1) CLKMD(0) PLLOCK(1) PLLOCK(0) PLLPM(1) PLLPM(0) Reserved PLLPS  */
/*   RW-x     RW-x      R-x       R-x       RW-0     RW-0             RW-0  */
/*                                                                          */
/* Note : -x = not affected by system reset, cleared to 0 by power on reset */

#define CLKMD_CLKIN             0x40	/* CPUCLK CLKIN ޵Ǵ Ŭ Ѵ.             */ 
#define CLKMD_DIV_2             0x00	/* CPUCLK CLKIN ޵Ǵ Ŭ 2 ؼ Ѵ.  */
#define CLKMD_PLL               0x80	/* CPUCLK PLL ⿡   Ŭ Ѵ.       */

#define PLLOCK_LOCKED           0x20	/* PLL Locked - PLL  ۵Ǿ Ÿ. */

#define PLLPS_DIV_4             0x00	/* SYSCLK CPUCLK 4   Ѵ.  */
#define PLLPS_DIV_2             0x01	/* SYSCLK CPUCLK 2   Ѵ.  */

#define PLLPM_IDLE_1            0x00	/* IDLE1 Mode - IDLE  low power mode  */
#define PLLPM_IDLE_2            0x04	/* IDLE2 Mode -   mode Ѵ.      */
#define PLLPM_PPD               0x08	/* PLL Power Down Mode                              */
#define PLLPM_OPD               0x0c	/* Oscillator Power Down Mode                       */


/*              ## Clock Control Register 1 (CKCR1-702Dh) ##                */
/*                                                                          */
/*    7        6        5        4        3         2        1        0     */
/* CKINF(3) CKINF(2) CKINF(1) CKINF(0) PLLDIV(2) PLLFB(2) PLLFB(1) PLLFB(0) */
/*   RW-x     RW-x     RW-x     RW-x     RW-x      RW-x     RW-x     RW-x   */
/*                                                                          */
/* Note : -x = not affected by system reset, cleared to 0 by power on reset */

#define CKINF_2         0xF0	/* 2Mhz - WatchDog Ÿ̸ Ŭ ùٸ */
#define CKINF_4         0xE0	/* 4Mhz	- ϱ Ͽ CLKIN ޵Ǵ  */
#define CKINF_6         0xD0	/* 6Mhz	- Ŭ ļ Ѵ.           */
#define CKINF_8         0xC0	/* 8Mhz                                     */
#define CKINF_10        0xB0	/* 10Mhz                                    */
#define CKINF_12        0xA0	/* 12Mhz                                    */
#define CKINF_14        0x90	/* 14Mhz                                    */
#define CKINF_16        0x80	/* 16Mhz                                    */
#define CKINF_18        0x70	/* 18Mhz                                    */
#define CKINF_20        0x60	/* 20Mhz                                    */

#define PLLDIV_1        0x00	/* CLKIN / 1	*/
#define PLLDIV_2        0x08	/* CLKIN / 2	*/

#define PLLFB_RATIO_1   0x00	/* CLKIN x 1	*/
#define PLLFB_RATIO_2   0x01	/* CLKIN x 2	*/
#define PLLFB_RATIO_3   0x02	/* CLKIN x 3	*/
#define PLLFB_RATIO_4   0x03	/* CLKIN x 4	*/
#define PLLFB_RATIO_5   0x04	/* CLKIN x 5	*/
#define PLLFB_RATIO_9   0x05	/* CLKIN x 9	*/


/*         ## GP Timer Control Register (TxCON : x=1, 2, and 3) ##          */
/*                                                                          */
/* Note : Addresses 7404h, 7408h, and 740Ch                                 */

#define EMULATION_FREE                      0x8000	/* Emulator   default  */
#define EMULATION_SOFT                      0x4000	/* Emulator ҽ                   */

#define STOP_HOLD_MODE                      0x0000	/* General Purpose Timer MODE  */
#define SINGLE_UP_COUNTING_MODE             0x0800
#define CONTINUOUS_UP_COUNTING_MODE         0x1000
#define DIRECTIONAL_UPDOWN_COUNTING_MODE    0x1800
#define SINGLE_UPDOWN_COUNTING_MODE         0x2000
#define CONTINUOUS_UPDOWN_COUNTING_MODE     0x2800

#define CLOCK_PS_1                          0x0000	/* Է Clock  Prescaler   */
#define CLOCK_PS_2                          0x0100
#define CLOCK_PS_4                          0x0200
#define CLOCK_PS_8                          0x0300
#define CLOCK_PS_16                         0x0400
#define CLOCK_PS_32                         0x0500
#define CLOCK_PS_64                         0x0600
#define CLOCK_PS_128                        0x0700

#define START_TIMER_WITH_TMR1               0x0080	/* TMR 2, 3 TMR 1 ȭ Ͽ Ҷ 	        */

#define TIMER_ENABLE                        0x0040	/* Ÿ̸Ӹ Enable ų                           */

#define TCLKS_INTERNAL                      0x0000	/* Input Clock Source                             */
#define TCLKS_EXTERNAL                      0x0010	/* ܺ Clock                                         */
#define TCLKS_TMR2                          0x0020	/* Timer 2, 3  32Bit Ÿ̸ӷ           */
#define TCLKS_QEP                           0x0030	/* QEP ȸ                                             */

#define TCLD_COUNTER0                       0x0000	/* Timer Compare(active) register reload condition      */
#define TCLD_COUNTER0_EPRV                  0x0004	/* equals period register value                         */
#define TCLD_IMMEDIATELY                    0x0008

#define TIMER_COMPARE_ENABLE                0x0002	/* Timer Compare Enable                                 */

#define USE_TMR1_PERIOD_REGISTER            0x0001	/* TMR 2, 3 PR ſ TMR 1 PR Ҷ           */


/*                 ## General Purpose Timer Function ##                     */
/*                                                                          */
/* . GET_TMRx_DIRECTION() - Get GP Timer x Status                           */
/*                        - return : COUNT_UP, COUNT_DOWN                   */
/*                                                                          */
/* . GET_TMRx_STATUS() - Get GP Timer x Enable bit Status                   */
/*                     - return : TMR_ENABLE, TMR_DISABLE                   */
/*                                                                          */
/* . TMRx_ENALBE() - Enable GP Timer x                                      */
/*                 - return : none                                          */

#define COUNT_DOWN                      0
#define COUNT_UP                        1

#define GET_TMR1_DIRECTION()            (((*GPTCON) & (0x2000)) >> 13)
#define GET_TMR2_DIRECTION()            (((*GPTCON) & (0x4000)) >> 14)
#define GET_TMR3_DIRECTION()            (((*GPTCON) & (0x8000)) >> 15)

#define GET_TMR1_STATUS()               (((*T1CON) & TIMER_ENABLE) >> 6)
#define GET_TMR2_STATUS()               (((*T2CON) & TIMER_ENABLE) >> 6)
#define GET_TMR3_STATUS()               (((*T3CON) & TIMER_ENABLE) >> 6)

#define TMR1_ENABLE()                   ((*T1CON) |= TIMER_ENABLE)
#define TMR2_ENABLE()                   ((*T2CON) |= TIMER_ENABLE)
#define TMR3_ENABLE()                   ((*T3CON) |= TIMER_ENABLE)


/*        ## General Purpose Timer Control Register (GPTCON-7400h) ##       */
/*                                                                          */
/* . Using ADC INT : *GPTCON = (SET_PERIOD_INT << START_ADC_BY_TMR2);       */
/*                                                                          */
/* . Setting Output Pin : *GPTCON = (ACTIVE_LOW << TMR2_OUPUT_PIN);         */

#define START_ADC_BY_TMR3               11
#define START_ADC_BY_TMR2               9
#define START_ADC_BY_TMR1               7

#define NO_EVENT                        0		/* No event starts ADC		*/
#define SET_UNDERFLOW_INT               1		/* underflow interrupt flag	*/
#define SET_PERIOD_INT                  2		/* period interrupt flag	*/
#define SET_COMPARE_INT                 3		/* compare interrupt flag	*/

#define COMPARE_OUTPUT_ENABLE           0x0040		/* All Compare Outputs Enable	*/

#define TMR3_OUTPUT_PIN                  4
#define TMR2_OUTPUT_PIN                  2
#define TMR1_OUTPUT_PIN                  0

#define FORCED_LOW                      0
#define ACTIVE_LOW                      1
#define ACTIVE_HIGH                     2
#define FORCED_HIGH                     3


/*              ## Compare Control Register (COMCON-7411h) ##               */
/*                                                                          */
/* . Note : Simple compare units & Full compare units shared.               */
/*                                                                          */
/* . Full Compare Mode Select : *COMCON = (PWM_MODE << FCMP_MODE1);         */

#define GLOBAL_COMPARE_ENABLE             0x8000	/* ü Compare Enable Ų.                */

#define FCLD_T1CNT0                       0x0000	/* Full Compare Register Reload           */
                                                	/* T1CNT = 0 ϶ .                       */
#define FCLD_T1CNT0_T1PR                  0x2000	/* Full Compare Register Reload           */
                                                	/* T1CNT = 0, T1PR = T1CNT ϶ .         */
#define FCLD_IMMEDIATELY                  0x4000	/* Full Compare Register Reload           */
                                                	/* Immediately .                          */

#define SVPWM_ENABLE                      0x1000	/* Space Vector PWM mode Enable Ų.       */

#define FACTRLD_T1CNT0                    0x0000	/* Full Compare Action Register Reload    */
                                                	/* T1CNT = 0 ϶ .                       */
#define FACTRLD_T1CNT0_T1PR               0x0400	/* Full Compare Action Register Reload    */
                                                	/* T1CNT = 0, T1PR = T1CNT ϶ .         */
#define FACTRLD_IMMEDIATELY               0x0800	/* Full Compare Action Register Reload    */
                                                	/* Immediately .                          */

#define FCO_ENABLE                        0x0200	/* Full Compare Output Enable Ų.         */
#define SCO_ENABLE                        0x0100	/* Simple Compare Output Enable Ų.       */

#define SC_SOURCE_TMR1                    0x0000	/* Simple Compare Source Clock Timer 1  */
#define SC_SOURCE_TMR2                    0x0080	/* Simple Compare Source Clock Timer 2  */

#define SCLD_T1CNT0                       0x0000	/* Simple Compare Register Reload         */
                                                	/* T1CNT = 0 ϶ .                       */
#define SCLD_T1CNT0_T1PR                  0x0020	/* Simple Compare Register Reload         */
                                                	/* T1CNT = 0, T1PR = T1CNT ϶ .         */
#define SCLD_IMMEDIATELY                  0x0040	/* Simple Compare Register Reload         */
                                                	/* Immediately .                          */

#define SACTRLD_T1CNT0                    0x0000	/* Simple Compare Action Register Reload  */
                                                	/* T1CNT = 0 ϶ .                       */
#define SACTRLD_T1CNT0_T1PR               0x0008	/* Simple Compare Action Register Reload  */
                                                	/* T1CNT = 0, T1PR = T1CNT ϶ .         */
#define SACTRLD_IMMEDIATELY               0x0010	/* Simple Compare Action Register Reload  */
                                                	/* Immediately .                          */

#define FCMP_MODE3                        2     	/* PWM6/CMP6, PWM5/CMP5 Mode Ѵ.      */
#define FCMP_MODE2                        1     	/* PWM4/CMP4, PWM3/CMP3 Mode Ѵ.      */
#define FCMP_MODE1                        0     	/* PWM2/CMP2, PWM1/CMP1 Mode Ѵ.      */

#define COMPARE_MODE                      0     	/* Compare Mode                                 */
#define PWM_MODE                          1     	/* PWM Mode                                     */


/*         ## Full Compare Action Control Register (ACTR-7431h) ##          */
/*                                                                          */
/* Setting Output Pin : *ACTR = (ACTIVE_LOW << FCMP1_OUTPUT_PIN);           */
/*                                                                          */
/* Setting Output Pin : *ACTR = (CMP_TOGGLE << FCMP2_OUTPUT_PIN);           */

#define SVPWM_DIR_POSITIVE          0x0000	/* CCW(Positive) Space-vector PWM rotation direction */
#define SVPWM_DIR_NEGATIVE          0x8000	/* CW(Negative) Space-vector PWM rotation direction  */

#define CMP_RESET                   0x0001	/* Reset  - Compare mode */
#define CMP_SET                     0x0002	/* Set    - Compare mode */
#define CMP_TOGGLE                  0x0003	/* Toggle - Compare mode */
#define CMP_HOLD                    0x0000	/* Hold   - Compare mode */

#define FCMP6_OUTPUT_PIN            10    	/* PWM6/CMP6 ouput pin   */
#define FCMP5_OUTPUT_PIN            8     	/* PWM5/CMP5 ouput pin   */
#define FCMP4_OUTPUT_PIN            6     	/* PWM4/CMP4 ouput pin   */
#define FCMP3_OUTPUT_PIN            4     	/* PWM3/CMP3 ouput pin   */
#define FCMP2_OUTPUT_PIN            2     	/* PWM2/CMP2 ouput pin   */
#define FCMP1_OUTPUT_PIN            0     	/* PWM1/CMP1 ouput pin   */


/*       ## Simple Compaare Action Control Register (SACTR-7414h) ##        */
/*                                                                          */
/* Setting Output Pin : *SACTR = (ACTIVE_LOW << SCMP1_OUTPUT_PIN);          */

#define SCMP3_OUTPUT_PIN            4	/* PWM9/CMP9 Output Pin	*/
#define SCMP2_OUTPUT_PIN            2	/* PWM8/CMP8 Output Pin	*/
#define SCMP1_OUTPUT_PIN            0	/* PWM7/CMP7 Output Pin	*/


/*           ## Dead-Band Timer Control Register (DBTCON-7415h) ##          */
/*                                                                          */
/* . Using DBT_PERIOD :	*DBTCON = (per << DBT_PERIOD);                      */
/*                                warnning : per - variable                 */

#define DBT_PERIOD                  8     	/* DB Timer ֱ⸦ ԷѴ.	*/

#define DBT3_ENABLE                 0x0080	/* PWM5/CMP5, PWM6/CMP6 DBT Enable Ų.	*/
#define DBT2_ENABLE                 0x0040	/* PWM3/CMP3, PWM4/CMP4 DBT Enable Ų.	*/
#define DBT1_ENABLE                 0x0020	/* PWM1/CMP1, PWM2/CMP2 DBT Enable Ų.	*/

#define DBT_PS_1                    0x0000	/* DB Timer Է Ŭ 1ָ Ѵ.	*/
#define DBT_PS_2                    0x0010	/* DB Timer Է Ŭ 2ָ Ѵ.	*/
#define DBT_PS_4                    0x0008	/* DB Timer Է Ŭ 4ָ Ѵ.	*/
#define DBT_PS_8                    0x0018	/* DB Timer Է Ŭ 8ָ Ѵ.	*/

/*                ## ADC Control Register 1 (ADC_CNTL1-7032h) ##            */
/*                                                                          */

#define ADC_EMU_FREE                0x4000	/* ADC ķ   ʵ Ѵ.      */

#define ADC_IMMEDIATELY_START       0x2000	/* ADC start converting immediately.                */

#define ENABLE_ADC1                 0x0800	/* Enable ADC 1  */
#define DISABLE_ADC1                0x0000	/* Disable ADC 1 */
#define ENABLE_ADC2                 0x1000	/* Enable ADC 2  */
#define DISABLE_ADC2                0x0000	/* Disable ADC 2 */

#define ADC_CONTINUOUS_MODE         0x0400	/* Sets the ADC unit for continuous conversion mode */

#define ADC_INT_ENABLE              0x0200	/* Enable interrupts                                */
#define ADC_INT_FLAG                0x0100	/* ADC interrupt flag bit                           */
                                          	/*  Ʈ set Ű flag clear ȴ.          */

#define ADC1_CHANNEL_0              0x0000	/* ADC1 Channel  */
#define ADC1_CHANNEL_1              0x0002
#define ADC1_CHANNEL_2              0x0004
#define ADC1_CHANNEL_3              0x0006
#define ADC1_CHANNEL_4              0x0008
#define ADC1_CHANNEL_5              0x000a
#define ADC1_CHANNEL_6              0x000c
#define ADC1_CHANNEL_7              0x000e

#define ADC2_CHANNEL_8              0x0000	/* ADC2 Channel  */
#define ADC2_CHANNEL_9              0x0010
#define ADC2_CHANNEL_10             0x0020
#define ADC2_CHANNEL_11             0x0030
#define ADC2_CHANNEL_12             0x0040
#define ADC2_CHANNEL_13             0x0050
#define ADC2_CHANNEL_14             0x0060
#define ADC2_CHANNEL_15             0x0070

#define ADC_START_CONVERSION        0x0001	/* ADC start of conversion */


/*                ## ADC Control Register 2 (ADC_CNTL2-7034h) ##            */
/*                                                                          */

#define ENABLE_ADC_START_BY_EV            0x0400	/* Enable conversion start by EV	*/
#define DISABLE_ADC_START_BY_EV           0x0000	/* Disable conversion start by EV	*/

#define ENABLE_ADC_START_BY_EXTERNAL      0x0200	/* Enable conversion start by ADCSOC pin	*/
#define DISABLE_ADC_START_BY_EXTERNAL     0x0000	/* Disable conversion start by ADCSOC pin	*/

#define ADC_PS_4                          0x0000	/* ADC input clock prescaler	*/
#define ADC_PS_6                          0x0001
#define ADC_PS_8                          0x0002
#define ADC_PS_10                         0x0003
#define ADC_PS_12                         0x0004
#define ADC_PS_16                         0x0005
#define ADC_PS_20                         0x0006
#define ADC_PS_32                         0x0007


/*                    ## ADC Control Register Function ##                   */
/*                                                                          */
/* . GET_ADC_CONVERSION_STATUS() - Get status of the ADC conversion.        */
/*                               - return : 0, 1                            */
/*                                                                          */
/* . GET_FIFOx_STATUS()	- Get status of the FIFOx                           */
/*                      - return : 0, 1, 2, 3                               */

#define END_OF_CONVERSION                 0
#define CONVERSION_PROGRESS               1

#define GET_ADC_CONVERSION_STATUS()       (((*ADC_CNTL1) & 0x0008) >> 3)

#define ADC_FIFO_EMPTY                    0
#define ADC_FIFO_ONE                      1
#define ADC_FIFO_TWO                      2
#define ADC_FIFO_LOST                     3

#define GET_FIFO1_STATUS()                (((*ADC_CNTL2) & 0x0018) >> 3)
#define GET_FIFO2_STATUS()                (((*ADC_CNTL2) & 0x00c0) >> 6)


/*               ## Capture Control Register (CAPCON-7420h) ##              */
/*                                                                          */
/* . Setting edge capture : *CAPCON = (DETECT_RISING << CAP1_EDGE);         */

#define CAPTURE_RESET                     0x0000	/* Clear Capture & QEP Register!	*/

#define CAPQEP_DISABLE                    0x0000	/* Disable capture units 1 and 2, and the QEP circuit */
#define CAPQEP_ENABLE_CAPTURE             0x2000	/* Enable only capture units 1 and 2                  */
#define CAPQEP_ENABLE_QEP                 0x6000	/* Enable only QEP circuit                            */

#define ENABLE_CAP3                       0x1000	/* Enable Capture Unit 3 */
#define ENABLE_CAP4                       0x0800	/* Enable Capture Unit 4 */

#define CAP34_SOURCE_TMR2                 0x0000	/* Capture Unit 3, 4 Ÿ̸Ӹ GP Timer 2  */
#define CAP34_SOURCE_TMR3                 0x0400	/* Capture Unit 3, 4 Ÿ̸Ӹ GP Timer 3  */

#define CAP12_SOURCE_TMR2                 0x0000	/* Capture Unit 1, 2 Ÿ̸Ӹ GP Timer 2  */
#define CAP12_SOURCE_TMR3                 0x0020	/* Capture Unit 1, 2 Ÿ̸Ӹ GP Timer 3  */

#define START_ADC_ON_CAP4INT              0x0010	/* Capture Unit 4 event starts ADC */

#define NO_DETECTION                      0
#define DETECT_RISING                     1
#define DETECT_FALLING                    2
#define DETECT_BOTH                       3

#define CAP1_EDGE                         6      	/* Set capture unit 1 edge detectioin control */
#define CAP2_EDGE                         4      	/* Set capture unit 1 edge detectioin control */
#define CAP3_EDGE                         2      	/* Set capture unit 1 edge detectioin control */
#define CAP4_EDGE                         0     	/* Set capture unit 1 edge detectioin control */


/*        ## SCI Communication Control Register (SCI_CCNTL-7050h) ##	    */
/*                                                                          */

#define SCI_STOP_BITS_1				0x00
#define SCI_STOP_BITS_2				0x80

#define SCI_ODD_PARITY				0x00
#define SCI_EVEN_PARITY				0x40

#define SCI_PARITY_DISABLE			0x00
#define SCI_PARITY_ENABLE			0x20

#define SCI_ENABLE    				0x10

#define SCI_IDLE_MODE				0x00
#define SCI_ADDRESS_MODE			0x08

#define SCI_CHAR_LENGTH_1			0x00
#define SCI_CHAR_LENGTH_2			0x01
#define SCI_CHAR_LENGTH_3			0x02
#define SCI_CHAR_LENGTH_4			0x03
#define SCI_CHAR_LENGTH_5			0x04
#define SCI_CHAR_LENGTH_6			0x05
#define SCI_CHAR_LENGTH_7			0x06
#define SCI_CHAR_LENGTH_8			0x07


/*              ## SCI Control Register 1 (SCI_CNTL1-7051h) ##              */
/*                                                                          */

#define SCI_RX_ERR_INT_DISABLE            0x00
#define SCI_RX_ERR_INT_ENABLE             0x40

#define SCI_SW_RESET_ENABLE               0x00
#define SCI_SW_RESET_DISABLE              0x20

#define SCI_INTERNAL_CLOCK_ENABLE         0x10
#define SCI_INTERNAL_CLOCK_DISABLE        0x00

#define SCI_TXWAKE_SELECT                 0x08
#define SCI_TXWAKE_NOTSELECT              0x00

#define SCI_SLEEP_DISABLE                 0x00
#define SCI_SLEEP_ENABLE                  0x04

#define SCI_TX_ENABLE                     0x02
#define SCI_TX_DISABLE                    0x00

#define SCI_RX_ENABLE                     0x01
#define SCI_RX_DISABLE                    0x00


/*              ## SCI Control Register 2 (SCI_CNTL2-7054h) ##              */
/*                                                                          */
/* . GET_SCI_TX_READY_STATUS() : get transmitter buffer-register ready flag */
/*                         return - 0 : SCITXBUF is full                    */
/*                                  1 : ready to receive the next character */
/*                                                                          */
/* . GET_SCI_TX_EMPTY_STATUS() : get transmitter empty flag.                */
/*                              return - 0 : tx buffer are loaded with data */
/*                                       1 : tx buffer are empty            */

#define GET_SCI_TX_READY_STATUS()         ((*SCI_CNTL2 & 0x80) >> 7)

#define GET_SCI_TX_EMPTY_STATUS()         ((*SCI_CNTL2 & 0x40) >> 6)

#define SCI_RX_INT_ENABLE                 0x02
#define SCI_RX_INT_DISABLE                0x00

#define SCI_TX_INT_ENABLE                 0x01
#define SCI_TX_INT_DISABLE                0x00


/*          ## Receiver Status Register (SCI_RX_STAT-7055h) ##              */
/*                                                                          */
/* . GET_SCI_RX_ERROR_STATUS() : SCI receiver-error flag.                   */
/*                                      return - 0 : no error flags are set */
/*                                               1 : error flags is set     */
/*                                                                          */
/* . GET_SCI_RX_READY_STATUS() : SCI receiver-ready flag.                   */
/*                                return - 0 : no new character in SCIRXBUF */
/*                                         1 : character ready to be read   */
/*                                                                          */
/* . GET_SCI_BRKDT_STATUS() : SCI break-detect flag.                        */
/*                                    return - 0 : no break condition       */
/*                                             1 : break condition occurred */
/*                                                                          */
/* . GET_SCI_FE_STATUS() : SCI framing-error flag.                          */
/*                                return - 0 : no framing error is detected */
/*                                         1 : framing error is detected    */
/*                                                                          */
/* . GET_SCI_OE_STATUS() : SCI overrun-error flag.                          */
/*                                return - 0 : no overrun error is detected */
/*                                         1 : overrun error is detected    */
/*                                                                          */
/* . GET_SCI_PE_STATUS() : SCI parity-error flag.                           */
/*                       return - 0 : no parity error or parity is disabled */
/*                                1 : parity error is detected              */
/*                                                                          */
/* . GET_SCI_RXWAKE_STATUS() : receiver wakeup-detect flag.                 */
/*                                 return - 0 : no wakeup condition occured */
/*                                          1 : wakeup condition detected   */

#define GET_SCI_RX_ERROR_STATUS()         ((*SCI_RX_STAT & 0x80) >> 7)

#define GET_SCI_RX_READY_STATUS()         ((*SCI_RX_STAT & 0x40) >> 6)

#define GET_SCI_BRKDT_STATUS()            ((*SCI_RX_STAT & 0x20) >> 5)

#define GET_SCI_FE_STATUS()               ((*SCI_RX_STAT & 0x10) >> 4)

#define GET_SCI_OE_STATUS()               ((*SCI_RX_STAT & 0x08) >> 3)

#define GET_SCI_PE_STATUS()               ((*SCI_RX_STAT & 0x04) >> 2)

#define GET_SCI_RXWAKE_STATUS()           ((*SCI_RX_STAT & 0x02) >> 1)


/*          ## Port Control Register 2 (SCI_PORT_C2-705eh) ##               */
/*                                                                          */

#define SCI_TXD_IO                  0x00
#define SCI_TXD_TRANSMIT            0x20

#define SCI_TXD_IO_INPUT            0x00
#define SCI_TXD_IO_OUTPUT           0x10

#define SCI_RXD_IO                  0x00
#define SCI_RXD_RECEIVE             0x02

#define SCI_RXD_IO_INPUT            0x00
#define SCI_RXD_IO_OUTPUT           0x01


/*           ## Priority Control Register (SCI_PRI-705fh) ##                */
/*                                                                          */

#define SCI_TX_PRIORITY_HIGH        0x00
#define SCI_TX_PRIORITY_LOW         0x40

#define SCI_RX_PRIORITY_HIGH        0x00
#define SCI_RX_PRIORITY_LOW         0x20

#define SCI_ESP_ENABLE              0x10	/* SCI emulator syspend enable */
#define SCI_ESP_DISABLE             0x00


/*               ## Interrupt Flag Register (IFR-0006h) ##                  */
/*                                                                          */

#define INTx_INIT_FLAG			0x3f

#define INT6_FLAG				0x20
#define INT5_FLAG				0x10
#define INT4_FLAG				0x08
#define INT3_FLAG				0x04
#define INT2_FLAG				0x02
#define INT1_FLAG				0x01


/*               ## Interrupt Mask Register (IMR-0004h) ##                  */
/*                                                                          */

#define INT6_MASK                   0x00
#define INT6_UNMASK                 0x20

#define INT5_MASK                   0x00
#define INT5_UNMASK                 0x10

#define INT4_MASK                   0x00
#define INT4_UNMASK                 0x08

#define INT3_MASK                   0x00
#define INT3_UNMASK                 0x04

#define INT2_MASK                   0x00
#define INT2_UNMASK                 0x02

#define INT1_MASK                   0x00
#define INT1_UNMASK                 0x01


/*               ## NMI Control Register (NMI_CNTL-7072h) ##                */
/*                                                                          */

#define NMI_FLAG                    0x8000

#define NMI_PIN_DATA_HIGH           0x0040
#define NMI_PIN_DATA_LOW            0x0000

#define NMI_POLARITY_RISING_EDGE    0x0004
#define NMI_POLARITY_FALLING_EDGE   0x0000

#define NMI_PRIORITY_HIGH           0x0000
#define NMI_PRIORITY_LOW            0x0002

#define NMI_ENABLE                  0x0001
#define NMI_DISABLE                 0x0000


/*              ## XINT1 Control Register (XINT1_CNTL-7070h) ##             */
/*                                                                          */

#define XINT1_FLAG                        0x8000

#define XINT1_PIN_DATA_HIGH               0x0040
#define XINT1_PIN_DATA_LOW                0x0000

#define XINT1_POLARITY_RISING_EDGE        0x0004
#define XINT1_POLARITY_FALLING_EDGE       0x0000

#define XINT1_PRIORITY_HIGH               0x0000
#define XINT1_PRIORITY_LOW                0x0002

#define XINT1_ENABLE                      0x0001
#define XINT1_DISABLE                     0x0000


/*              ## XINT2 Control Register (XINT2_CNTL-7078h) ##             */
/*                                                                          */

#define XINT2_FLAG                        0x8000

#define XINT2_PIN_DATA_HIGH               0x0040
#define XINT2_PIN_DATA_LOW                0x0000

#define XINT2_DATA_DIR_INPUT              0x0000
#define XINT2_DATA_DIR_OUTPUT             0x0010

#define XINT2_DATA_OUT_LOW                0x0000
#define XINT2_DATA_OUT_HIGH               0x0008

#define XINT2_POLARITY_RISING_EDGE        0x0004
#define XINT2_POLARITY_FALLING_EDGE       0x0000

#define XINT2_PRIORITY_HIGH               0x0000
#define XINT2_PRIORITY_LOW                0x0002

#define XINT2_ENABLE                      0x0001
#define XINT2_DISABLE                     0x0000


/*              ## XINT3 Control Register (XINT3_CNTL-707ah) ##             */
/*                                                                          */

#define XINT3_FLAG                        0x8000

#define XINT3_PIN_DATA_HIGH               0x0040
#define XINT3_PIN_DATA_LOW                0x0000

#define XINT3_DATA_DIR_INPUT              0x0000
#define XINT3_DATA_DIR_OUTPUT             0x0010

#define XINT3_DATA_OUT_LOW                0x0000
#define XINT3_DATA_OUT_HIGH               0x0008

#define XINT3_POLARITY_RISING_EDGE        0x0004
#define XINT3_POLARITY_FALLING_EDGE       0x0000

#define XINT3_PRIORITY_HIGH               0x0000
#define XINT3_PRIORITY_LOW                0x0002

#define XINT3_ENABLE                      0x0001
#define XINT3_DISABLE                     0x0000


/*                    ## Interrupt vector setting ##                        */
/*                                                                          */

asm("	.sect	\".vector1\"    "); 
asm("	.global	_c_int0         ");

asm("	b	_c_int0         "); 
asm("	b	_c_int1         "); 
asm("	b	_c_int2         "); 
asm("	b	_c_int3         "); 
asm("	b	_c_int4         "); 
asm("	b	_c_int5         "); 
asm("	b	_c_int6         ");

asm("	.text                   ");
asm("PHANTOM	.set	0       ");

#ifndef INT1
asm("_c_int1	b	PHANTOM	");
#endif

#ifndef INT2
asm("_c_int2	b	PHANTOM	");
#endif

#ifndef INT3
asm("_c_int3	b	PHANTOM	");
#endif

#ifndef INT4
asm("_c_int4	b	PHANTOM	");
#endif

#ifndef INT5
asm("_c_int5	b	PHANTOM	");
#endif

#ifndef INT6
asm("_c_int6	b	PHANTOM	");
#endif


#endif