/*****************************************************************************************/
/*											 */	
/* Description : TMS320F240 Header file with all Peripheral Register declarations	 */	
/*		 plus other useful defines.						 */	
/*											 */	
/*****************************************************************************************/

#ifndef		__REGISTER_H
#define		__REGISTER_H

/*--------------------------------------------------------------*/
/* On Chip Periperal Register Definitions (DATA SPACE)		*/
/*--------------------------------------------------------------*/

/*
	R:READ ACCESS
	W:WRITE ACCESS
	C:CLEAR-ONLY WRITE ACCESS 
	W1C:WRITE 1 TO CLEAR
	*:NOT AFFECTED BY RESET, SET TO 1 BY POWER-ON RESET

	P:SET TO 1 BY POWER ON RESET
	I:VALUE OF VCCP PIN LATCH ON RISING EDGE OF RESET
*/


/* C2xx Core Registers */

#define		IMR		(int *)0x0004			/* Int Mask Register */
/*
	0000 0000 0000 0000
    15-6:reserved 5-0(RW):INT6-1
*/
#define 	GREG		(int *)0x0005		/* Global memory allocation reg */
#define		IFR		(int *)0x0006			/* Int Flag Register */
/*
	0000 0000 0000 0000
    15-6:reserved 5(WR1C):INT6-1
*/
#define		ABRPT		(int *)0x001F			/* Analysis BreakPoint Register */

/* System Module Registers */

#define		SYSCR		(int *)0x7018			/* System Module Control Register */
/*
	01XX XXXX PPXX XXXX
	15(RW):RESET1 14(RW):RESET0 13-8:RESERVED 7-6(RW*):CLKSRC1-0 5-0(RW*):RESERVED
*/
#define		SYSSR		(int *)0x701A			/* System Module Status Register */
/*
	XXXX XXXX XXIX 1XXO
	15(RC):PORST 14-13:RESERVED 12(RC):ILLADR 11:RESERVED	10(RC):SWRST 9(RC):WDRST
	8-6:RESERVED 5(RC):HPO 4:RESERVED 3(R):VCCAOR 2-1:RESERVED 0(R):VECRD
*/
#define		DIN		(int *)0x701C			/* Device Identification Register */

#define		SYSIVR		(int *)0x701E			/* System Interrupt Vector Register */ 
/*
	0000 0000 0000 0000
	15-0:SYSTEM INTERRUPT VECTOR
*/
#define		XINT1_CNTL	(int *)0x7070			/* Int1 (type A) Control reg */
/*
	15:XINT1 FLAG	14-7:RESERVED	6:XINT1 PIN DATA	5:XINT1 NMI ENABLE
	4-3:RESERVED	2:XINT1 POLARITY	1:XINT1 PRIORITY	0:XINT1 ENABLE
*/
#define		NMI_CR	(int *)0x7072			/* Non maskable Int (type A) Control reg */
/*
	15:NMI FLAG	14-7:RESERVED	6:NMI PIN DATA	5:NMI ENABLE
	4-3:RESERVED	2:NMI POLARITY	1-0:RESERVED
*/
#define		XINT2_CR	(int *)0x7078			/* Int2 (type C) Control reg */
/*
	15:XINT2 FLAG	14-7:RESERVED	6:XINT2 PIN DATA	5:RESERVED	4:XINT2 DATA DIR	
	3:XINT2 DATA OUT 	2:XINT2 POLARITY	1:XINT2 PRIORITY	0:XINT2 ENABLE
*/
#define		XINT3_CR	(int *)0x707A			/* Int3 (type C) Control reg */
/*
	15:XINT3 FLAG	14-7:RESERVED	6:XINT3 PIN DATA	5:RESERVED	4:XINT3 DATA DIR	
	3:XINT3 DATA OUT 	2:XINT3 POLARITY	1:XINT3 PRIORITY	0:XINT3 ENABLE
*/
#define		PDPINT_CR	(int *)0x742C		/* Power Drive Protection Int cntl reg */

/* Digital I/O */

#define		OCRA		(int *)0x7090			/* I/O MUX Control Reg A */
/*
	0000 0000 0000 0000
	15-0(RW):CRA15-0  

		0 = Set corresponding output pin or internal control line low
		1 = Set corresponding output pin or internal control line high
*/
#define		OCRB		(int *)0x7092			/* I/O MUX Control Reg B */
/*
	0000 0000 0000 0000
	15-0(RW):CRB15-0  
	0 = Set corresponding output pin or internal control line low
	1 = Set corresponding output pin or internal control line high
*/
#define		IPSRA		(int *)0x7094			/* Input Status Reg A */
/*
	0000 0000 0000 0000
	15-0(RW):IPA15-0  
	0 = Corresponding input pin or internal signal is low
	1 = Corresponding input pin or internal signal is high
*/
#define		IPSRB		(int *)0x7096			/* Input Status Reg B */
/*
	0000 0000 0000 0000
	15-0(RW):IPB15-0  
	0 = Corresponding input pin or internal signal is low
	1 = Corresponding input pin or internal signal is high
*/
#define		PADATDIR	(int *)0x7098			/* I/O port A Data & Direction reg. */
/*
	0000 0000 0000 0000	
	15-12:RESERVED	11-8:A3-0DIR 7-4:RESERVED 3-0:IOPA3-0
*/
#define		PBDATDIR	(int *)0x709A			/* I/O port B Data & Direction reg. */
/*
	0000 0000 0000 0000	
	15-8:B7-0DIR	7-0:IOPB7-0
*/
#define		PCDATDIR	(int *)0x709C			/* I/O port C Data & Direction reg. */
/*
	0000 0000 0000 0000	
	15-8:C7-0DIR 7-0:IOPC7-0
*/
#define		PDDATDIR	(int *)0x709E			/* I/O port D Data & Direction reg. */
/* 
	15-8(RW):x7DIR-x0DIR  
	0 = Configure corresponding pin as an INPUT
	1 = Configure corresponding pin as an OUTPUT

	7-0(RW):IOPx7-IOPx0
	If xnDIR  = 0,then:
	0 = Corresponding I/O pin is read as a LOW
	1 = Corresponding I/O pin is read as a HIGH  

	If xnDIR  = 1,then:
	0 = Corresponding I/O pin is read as a HIGH
	1 = Corresponding I/O pin is read as a LOW  
*/

/* Watch-Dog(WD) / Real Time Int(RTI) / Phase Lock Loop(PLL) Registers */

#define		RTI_CNTR		(int *)0x7021			/* RTI Counter reg */
/*
	0000 0000 0000 0000
	15-8:RESERVED 
	7-0:D7-0  \\ Data values. These read only data bits contains the 8-bits RTI counter value
                     Writing any value to this register clears it to 0
*/
#define		WD_CNTR 	(int *)0x7023			/* WD Counter reg */
/*
	0000 0000 0000 0000
	15-8:RESERVED 
	7-0:D7-0  \\ Data values. These read only data bits contains the 8-bits WD counter value
                     Writing any value to this register has no effect
*/
#define		WD_KEY		(int *)0x7025			/* WD Key reg */
/*
	0000 0000 0000 0000
	15-8:RESERVED 
	7-0:D7-0  \\ Data values. These read only data bits contains the 8-bits WD reset key value
                     When read, WDKEY does not return the last key value but rqather returns
                     the counters of WDCR 
*/
#define		RTI_CNTL	(int *)0x7027			/* RTI Control reg */
/*
	0000 0000 0000 0000
	15-8:RESERVED 
	7:RTI FLAG  \\ Real-time interrupt flag bit
		0 = Overflow has not occured
		1 = Overflow has occured 	
	
	6:RTI ENA  \\ Real-time interrupt enable bit
		0 = Clear any pending interrupt request acknowledged and disables future RTI interrupts
		1 = Enables interrupts to be generated when RTI flag detects an overflow  	
		
	5-3:RESERVED  \\ Writing to these bits has no effect. These bits always read as 0 	
	2-0:RTIPS2-0  \\ Real-time interrupt prescale select bits
	
	* Table 6-3 Real-Time Interrupt Selection
	--------------------------------------------------------------------------------------------
          RTI Prescale Select Bits                    16.384kHz WDCLK           15.625kHz WDCLK
	----------------------------              ------------------------  ------------------------  
	                                 WDCLK      Frequency   Overflow      Frequency   Overflow
	   TIPS2   RTIPS1   RTIPS0      Divider       (Hz)        time          (Hz)        time 
	--------------------------------------------------------------------------------------------
	     0       0        0             4        4096       244.14 us      3906.25       256 us    
	     0       0        1            16        1024       976.56 us       976.56     1.024 ms    
	     0       1        0            64         256         3.91 ms       244.14     4.096 ms    
	     0       1        1           128         128         7.81 ms       122.07     8.192 ms    
	     1       0        0           256          64        15.63 ms        61.04    16.384 ms    
	     1       0        1           512          32        31.25 ms        30.52    32.768 ms    
	     1       1        0          2048           8       125.00 ms         7.63   131.072 ms    
	     1       1        1         16384           1         1.0   s         0.95     1.049 s 
	--------------------------------------------------------------------------------------------   
	     
*/
#define		WD_CNTL 	(int *)0x7029			/* WD Control reg */
/*
	0000 0000 X000 0000
	15-8:RESERVED 
	
	7:WDFLAG  \\ Watchdog flag bit
		0 = Indicates that the WD timer has not asserted a reset since the bit was last cleared
		1 = Indicates that the WD timer has asserted a reset since the bit was last cleared	
	6:WDDIS  \\ Watchdog disable 
		0 = Watchdog is enabled
		1 = Watchdog is disabled
	5(RW):WDCHK2  \\  Watchdog check bit2
		0 = System reset is asserted 
		1 = Normal operation continues if all check bits are written correctly 
    4(RW):WDCHK2  \\  Watchdog check bit1
		1 = System reset is asserted 
		0 = Normal operation continues if all check bits are written correctly 
	3(RW):WDCHK0  \\  Watchdog check bit0
		0 = System reset is asserted 
		1 = Normal operation continues if all check bits are written correctly 
	2-0:WDPS2-0  \\ Watchdog prescale select bits

	* Table 6-4 WD Overflow (Timeout)  Selection
	--------------------------------------------------------------------------------------------
          WD Prescale Select Bits                    16.384kHz WDCLK           15.625kHz WDCLK
	----------------------------              ------------------------  ------------------------  
	                                 WDCLK      Frequency   minimum      Frequency     Minimum
	   WDPS2   WDPS1   WDPS0        Divider       (Hz)      overflow       (Hz)        overflow
	--------------------------------------------------------------------------------------------
	     0       0        X             1          64        15.63 ms       61.04       16.38 ms    
	     0       1        0             2          32        31.25 ms       30.52       32.77 ms    
	     0       1        1             4          16        62.50 ms       15.26       65.54 ms    
	     1       0        0             8           8       125.00 ms        7.63      131.07 ms    
	     1       0        1            16           4       250.00 ms        3.81      262.14 ms    
	     1       1        0            32           2       500.00 ms        1.91      524.29 ms    
	     1       1        1            64           1         1.0   s        0.95        1.05  s 
	--------------------------------------------------------------------------------------------   
	
*/
#define		PLL_CNTL1	(int *)0x702B			/* PLL control reg 1 */
/*
	0000 0000 XXXX 00X0
	15-8:RESERVED 
	7-6:CLKMD1-0  // Read/Write bits.This bits select the operation mode of the clock module

		--------------------------------
		  CLKMD(1:0)    Mode 
		--------------------------------
		      00       CLKIN/2      
                      01       CLKIN
		      10       PLL Enabled
		      11       PLL Enabled
		--------------------------------

	5-4:PLLOCK1-0  \\ read only bits
		0 = PLL not locked - running off Clock in 
		1 = PLL locked and running off PLL Clocks 
	3-2:PLLPM1-0  \\ Read/Write bits
	1:ACLKENA  \\ Read/Write bit
		0 = ACLK disabled(stopped)
		1 = ACLK enabled 
	0:PLLPS  \\ Read/Write bit
		0 = f(SYSCLK) = f(CPUCLK) /4
		1 = f(SYSCLK) = f(CPUCLK) /2 
*/
#define		PLL_CNTL2	(int *)0x702D			/* PLL control reg 2 */
/*
	XXXX XXXX XXXX XXXX
	15-8:RESERVED 
	7-4(RW):CKINF3-0  \\ Read/Write bit

	*Table 10-8 CKINF(3:0) Bits vs Clock-in Frequency 
	----------------------------------------------------------------------    
	  CKINF(3:0)     Frequency(MHz)        CKINF(3:0)     Frequency(MHz) 
	---------------------------------    ---------------------------------
            0000              32                 1000              16
            0001              30                 1001              14 
            0010              28                 1010              12 
            0011              26                 1011              10
            0100              24                 1100               8
            0101              22                 1101               6
            0110              20                 1110               4 
            0111              18                 1111               2 
	----------------------------------------------------------------------              

	3:PLLDIV2  \\ Read/Write bit

		0 = Do not divide Pll input
		1 = Divide PLL input by 2
 
	2-0:PLLFB2-0  \\ Read/Write bits

	*Table 10-9 PLLFB(2:0) Bits vs PLL Multiplication Ratio  
	-------------------------------------------    
	  PLLFB(2:0)     PLL Multiplication Ratio
	-------------------------------------------
            000                      1 
	    001                      2 
            010                      3 
            011                      4
            100                      5
            101                      9
            110                      1 
            111                      1
	-------------------------------------------              
*/	

/* Analog-to-Digital Converter(ADC) registers */

#define		ADC_CNTL1		(int *)0x7032			/* ADC Control reg 1 */
/*
	0000 0000 0000 0000
	15(RW):SUSPEND SOFT  \\ Applicable only during emulation. this bit is not shadowed
		0 = Stop immediately when suspend-free (bit 14)=0
		1 = Complete conversion before halting emulator
	14(RW):SUSPEND FREE	 \\ Applicable only during emulation. this bit is not shadowed
		0 = Operation is determined by suspend-soft (bit 15)
		1 = Keep running on emulator suspend 
	13(RW):ADCIMSTART  \\ ADC start converting immediately. This bit is not shadowed.
		0 = No action 
		1 = Immediate start of conversion
 	12(SRW):ADC2EN  \\ Enable/disable bit for ADC2. This bit is shadowed. 
                      This bit can be written to while a conversion is going on. 
                      The effect of writing to this bit is observed during the next conversion.
		0 = ADC2 disabled.(No sample/hold/conversion can take place; data register FIFO1 does not change.)
		1 = ADC2 is enabled     
	11(SRW):ADC1EN  \\ Enable/disable bit for ADC1. This bit is shadowed. 
                      This bit can be written to while a conversion is going on. 
                      The effect of writing to this bit is observed during the next conversion.
		0 = ADC1 disabled.(No sample/hold/conversion can take place; data register FIFO1 does not change.)
		1 = ADC1 is enabled
	10(SRW):ADCCONRUN  \\ This bit sets the ADC unit for continuous conversion mode.
                         This bit is shadowed. This bit can be written to while a conversion is going on. 
                         The effect of writing to this bit is observed during the next conversion.	
		0 = No action 
		1 = Continuous conversion

	9(SRW):ADCINTEN  \\ Enable interrups. If the ADCINTEN bit is set, an interrup is requested when the ADCINTFLAG is set. 
                            This bit is cleared on reset and is shadowed. This bit can be written to while a conversion is going on. 
                            The effect of writing to this bit is observed during the next conversion.	
  
	8(RW):ADCINTFLAG  \\ ADC interrupt flag bit. This bit indicates whether an interrupt event has occured. 
                             Writing a 1 to ADCINTFLAG cleares the bit. this bit is not shadowed.
                          
		0 = No interrupt event occured
                1 = An interrupt event occured
 
	7(R):ADCEOC  \\ This bit indicates the status of the ADC conversion. This bit is not shadowed.  	

		0 = End of conversion 
                1 = Conversion is in progress
 
	6-4(SRW):ADC2CHSEL  \\ Select channels for ADC2. This is shadowed. This bit can be written to while a previous conversion is going on.
                               The effect of writing to this bit is observed during the next conversion

		000 = Channel 9   	
		001 = Channel 10   	
		010 = Channel 11   	
		011 = Channel 12   	
		100 = Channel 13   	
		101 = Channel 14   	
		110 = Channel 15   	
		111 = Channel 16   	
		

	3-1(SRW):ADC1CHSEL  \\ Select channels for ADC1. This is shadowed. It can be written to while a previous conversion is going on.
                               The effect of writing to this bit is observed during the next conversion

		000 = Channel 1   	
		001 = Channel 2   	
		010 = Channel 3   	
		011 = Channel 4   	
		100 = Channel 5   	
		101 = Channel 6   	
		110 = Channel 7   	
		111 = Channel 8   	
			
	0(SRW):ADCSOC  \\ ADC start of conversion (SOC) bit. This bit is shadowed. It can be written to while a previous conversion is going on.
                               The effect of writing to this bit is observed during the next conversion

		0 = No action
		1 = Start converting  
-----------------------------------------------------------------------------------------------
    *^.^*   Note: Either channel 1 or channel 2 must be enabled before a conversion can start
-----------------------------------------------------------------------------------------------
*/
#define		ADC_CNTL2		(int *)0x7034			/* ADC Control reg 2 */
/*
	XXXX X00X 00X0 0000
	15-11:RESERVED  \\ Reads are indeterminate and writes have no effect
		
	10(SRW):ADCEVSOC  \\ Event manager SOC mask bit. When set, the ADC converion can be sychronized with an event manager signal
                        The evet manager can start a conversion, depending on the outcome of a compare match. 
						This bit is shadowed and functions on any other previously described shadowed bit.
		0 = Mask ADCEVSOC (disable conversion start by EV)
		1 = Enable conversion start by EV
   	
	9(SRW):ADCEXTSOC  \\ External signal mask bit. When set, the ADC conversion can be sychronized with an external signal. 
                             ADC conversion starts with the rising edge of the external signal. This bit is shadowed.
	8(SRW):RESERVED  \\ Reads are indeterminate and writes have no effect
	7-6(R):ADCFIFO2  \\ Date register FIFO2 status. These two bits indicate ADC2FIFO status. Two conversion results canbe stored before performing
                            any read operations. However, after two conversions, if the third conversions is made the oldest results is lost.
                            This bits are not shadowed.   
		00 = FIFO2 is empty
		01 = FIFO2 has one entry
		10 = FIFO2 have two entries
       	11 = FIFO2 had two entries and another entry was received; the first entry was loat. 

	5:RESERVED  \\ Reads are indeterminate and writes have no effect
	4-3(R):ADCFIFO1  \\ Date register FIFO2 status. These two bits indicate ADC2FIFO status. Two conversion results canbe stored before performing
                            any read operations. However, after two conversions, if the third conversions is made the oldest results is lost.
                            This bits are not shadowed.   
 	2-0(R):ADCPSCALE  \\ ADC input clock prescaler. These bits define the ADC clock prescaler. Sample prescaler times are explained in section 3.2.3
                             Analog Signal Sampling/Conversion , on page 3-5. See the following table for prescaler values.

			     ------------------------------------------       	
				ADCSCALE Bits 
			     ----------------------    Prescale Value    	
		       Bit2   Bit1   Bit0	
			     ------------------------------------------	
				0       0      0             4    			         	
				0       0      1             6    			         	
				0       1      0             8    			         	
				0       1      1             10    			         	
				1       0      0             12    			         	
				1       0      1             16    			         	
				1       1      0             20    			         	
				1       1      1             32    			         	
			     ------------------------------------------	
*/
#define		ADC_FIFO1		(int *)0x7036			/* ADC FIFO data reg 1 */
#define		ADC_FIFO2		(int *)0x7038			/* ADC FIFO data reg 2 */
/* The structure of 7036h & 7038h are same 
   Default values are empty 	
	15-6:D9-0  \\ Actual 10-bit converted data
    5-0:RESERVED  \\ Always read as 0
*/ 	

/* Serial Peripheral Interface (SPI) Registers */

#define		SPI_CCR 		(int *)0x7040			/* SPI Config Control Reg 1 */
/*
	XXXX XXXX 00XX X000
	15-8:RESERVED

        7:SPI SW RESET  \\ SPI software reset

		0 = SPI is ready to transmit or receive the next character
                1 = Inintializes the SPI operating flags to the reset condition

        6:CLOCK POLARITY  \\ Shift clock polarity

   		0 = Inactive level is low
                1 = Inacive level is high

        5-3:RESERVED  \\ Reads are indeterminate and writes have no effect

        2-0:SPICHAR2-0  \\ Character length control bits
      
                ---------------------------------------------------------------
   	          SCI CHAR2   SCI CHAR1  SCI CHAR0    Character Length (Bits)
		---------------------------------------------------------------
                      0           0          0                 1
                      0           0          1                 2
                      0           1          0                 3
                      0           1          1                 4
                      1           0          0                 5
                      1           0          1                 6
                      1           1          0                 7
                      1           1          1                 8
                ---------------------------------------------------------------
*/

*/
#define		SPI_CNTL 		(int *)0x7041			/* SPI Operation Control Reg 2 */
/*
	XXXX XXXX XXX0 0000
	15-8:RESERVED  \\ Reads are indeterminate and writes have no effect

	7-5:RESERVED  \\ Reads are indeterminate and writes have no effect
 
	4(RW):OVERRUN INT ENA  \\ Overrninterrupt enable

		0 = Disable RECEIVER OVERRUN flag bit (SPISTS.7) interrupts  
		1 = Enable RECEIVER OVERRUN flag bit (SPISTS.7) interrupts  

	3(RW):CLOCK PHASE  \\ SPI clock Phase Select

		0 = Normal SPI clocking scheme, depending onthe CLOCK POLARITY bit 
		1 = SPICLK signal delayed by one half-cycle, Polarity determined by the CLOCK POARITY bit
   
	2(RW):MASTER/SLAVE  \\ SPI network mode control

		0 = SPI configured as a slave
		1 = SPI configured as a master  

	1(RW):TALK  \\ Master/Slave transmit enable 

		0 = Disable transmission
		1 = Enable transmission
  
	0(RW):SPI INT ENA  \\ SPI interrupt Enable

		0 = Disable interrupt
		1 = Enables interrupt 
*/
#define		SPI_STAT 		(int *)0x7042			/* SPI Status Reg */
/*
	XXXX XXXX 00XX XXXX
	15-8:RESERVED 
	
	7(RC):RECEIVER OVERRUN  \\ SPI receiver overrun flag 
	
	6(R):SPI INT  \\ SPI interrupt flag
 
	FLAG 5-0:RESERVED  \\ Reads are indeterminate and writes have no effect
 
*/
#define		SPI_BAUD 		(int *)0x7044			/* SPI Baud rate control reg */
/*
	XXXX XXXX X000 0000
	15-8:RESERVED  \\ Reads are indeterminate and writes have no effect
  
	7:RESERVED  \\ Reads are indeterminate and writes have no effect
  
	6-0(RW):SPI BIT RATE6-0  \\ SPI bit rate control (determine the bit transfer rate if the SPI is the network master)
*/
#define		SPI_EMUBUF 		(int *)0x7046			/* SPI Emulation buffer reg */
/*
	XXXX XXXX XXXX XXXX
	15-8:RESERVED  \\ Reads are indeterminate and writes have no effect
  
	7-0(R):ERCVD7-0  \\ Emulation buffer received data
*/
#define		SPI_RXBUF 		(int *)0x7047			/* SPI Serial Input buffer reg */
/*
	XXXX XXXX XXXX XXXX
	15-8:RESERVED  \\ Reads are indeterminate and writes have no effect
  
	7-0(R):RCVD7-0  \\ Received data (SPIDAT receives the complete character, the character is transferred to SPIBUF)
*/
#define		SPI_DATA 		(int *)0x7049			/* SPI Serial Data reg */
/*
	XXXX XXXX XXXX XXXX
	15-8:RESERVED  \\ Reads are indeterminate and writes have no effect
  
	7-0(RW):SDAT7-0  \\ Serial data. Writing to the SPIDAT performs two functions
*/
#define		SPI_PORTCNTL1 		(int *)0x704D			/* SPI Port control reg1 */
/*
	XXXX XXXX X000 X000
	15-8:RESERVED  \\ Reads are indeterminate and writes have no effect
 
	7(R):SPISTE DATA IN  \\ SPI slave transmit enable data in flag
 
	6(RW):SPISTE DATA OUT  \\ SPI slave transmit enable data out flag  
		                  the SPISTE pin in the slave mode acts as an SPI module select When this occurs there is no attempt to write 
                                  a value out on the SPISTE pin. However the SPISTE pin can be used as an general purpose digitl I/O pin  in the
                                  slave mode   		
                    
	5(RW):SPISTE FUNCTION  \\ SPI slave transmit enable pin function select  

		@ Master mode
		     * The SPISTE FUNCTION bit has no effect on the SPISTE bit has no effect on the SPISTE pin in the master mode
		     * The SPISTE pin always functions as a general purpose I/O pin

		@ Slave Mode 
		     
		     0 = SPISTE pin functions as a general purpose I/O pin
		     1 = SPISTE pin functions as the SPI module select pin
 		   	 
	4(RW):SPISTE DATA DIR  \\ SPI slave transmit enable pin data direction

		0 = SPISTE is configured as an input pin
		1 = SPISTE is configured as an output pin

	3(R):SPICLK DATA IN  \\ SPICLK pin port data in flag

	2(RW):SPICLK DATA OUT  \\ SPICLK pin port data out
 
	1(RW):SPICLK FUNCTION  \\ SPICLK pin function select

		0 = SPICLK is a general-purpose digital I/O pin
		1 = SPICLK pin contains the SPI clock
  
	0(RW):SPICLK DATA DIR  \\ SPICLK data direction

		0 = SPICLK pin is an input pin
		1 = SPICLK pin is an output pin
*/
#define		SPI_PORTCNTL2 		(int *)0x704E			/* SPI Port control reg2 */
/*
	XXXX XXXX X000 X000
	15-8:RESERVED 
	7(R):SPISIMO DATA IN  \\ SPISIMO pin data in
	
	6(RW):SPISIMO DATA OUT  \\ SPISIMO pin data out 

		* The SPISIMO pin is defined as general-purpose digital I/O pin(SPISIMO FUNCTION=0)
		* The SPISIMO pin data direction is defined as output(SPISIMO DATA DIR=1)
 
	5(RW):SPISIMO FUNCTION  \\ SPISIMO pin function select

		0 = The SPISIMO pin is a general purpose digital I/O pin
		1 = The SPISIMO pin contains the SPI data 

	4(RW):SPISIMO DATA DIR  \\ SPISIMO data direction

		0 = The SPISIMO pin is a general purpose digital I/O pin
		1 = The SPISIMO pin contains the SPI data 

	3(R):SPISOMI DATA IN  \\ SPISOMI pin data in. 
 
	2(RW):SPISOMI DATA OUT  \\ SPISOMI pin data out 

	1(RW):SPISOMI FUNCTION  \\ SPISOMI pin function select.

		0 = The SPISOMI pin is a general-purpose digital I/O pin
		1 = The SPISOMI pin contains the SPI data
   
	0(RW):SPISOMI DATA DIR  \\ SPISOMI data direction 

		0 = The SPISOMI pin is an input pin
		1 = The SPISOMI pin is an output pin
*/
#define		SPI_PRIORITY 		(int *)0x704F			/* SPI Priority control reg */
/*
	XXXX XXXX X00X XXXX
	15-8:RESERVED 

	7:RESERVED 

	6(RW):SPI PRIORITY  \\ Interrupt priority select.
 
		0 = Interrupts are high priority requests 		 
		1 = Interrupts are low priority requests 		 

	5(RW):SPI ESPEN  \\ Emulator suspend enable

		0 = When the emulator is suspended, the SPI continues to work 
                    until the current transmit/receive sequence is complete 
		1 = When the emulator is suspended, the state of SPI is frozen 
                    so that it can be examined at the point that the emulator was suspended
 
	4-0:RESERVED
*/

/* Serial Communications Interface (SCI) Registers */

#define		SCI_CCNTL		(int *)0x7050			/* SCI Comms Control Reg */
/*
	15-8:RESERVED 

	7(RW):STOP BIT  \\ SCI number of stop bits. This bit specfies the number of stop bits transmitted. 
                           The receiver checks for only one stop bit. 
                     
		0 = One stop bit
		1 = twostop bits
                     
	6(RW):EVEN/ODD PARITY  \\ SCI parity odd/even selection. If the PARITY ENABLE bit(SCICCR.5) is set. 
                                  PARITY(bit 6) designates odd or even parity(odd or even number of bits wuth the value
                                  of 1 in both transmitted and received characters)

		0 = Odd parity
		1 = Even parity
       
	5(RW):PARITY ENABLE  \\ SCI parity enable. This bit enabes or disables the parity function. 
                                If the SCI is in the address-bit multiprocessor mode(set using bit 3 of this register),
                                the address bit is includes in the parity calculation(if parity is enabled).
                                For characters of less than eight bits, the remaining unused bits must be masked out of the
                                parity calculation

		0 = Parity disabled; No parity bit is generated during transmission or is expected during reception.
		1 = Parity is enabled
   
	4(RW):SCI ENA  \\ SCI communication enable bit. this bit must be set to 1 for correct operation
	
	3(RW):ADDR/IDLE MODE  \\ SCI multiprocessor mode control bit. This bit selects one of the multiprocessor protocols

		0 = Idle-line mode protocol is selected
		1 = Address-bit mode protocol is selected

                multi processor communication is different from the other communication modes because it uses SLEEP anf TXWAKE functions(bit SCICTL1.2
                and SCICTL1.3,respectively). (Both of these bit are further describrd in section4.3,
                SCI Multiprocessor Communication, on page 4-8).  The idle-line mode is usually used for normal communications because the addressbit
                mode adds an extra bit to the frame. The idle-line mode does not add this extra bit and is compatible for SCI CHAR2-0 bits
 
	2-0(RW):SCI CHAR2-0  \\ Character-length control bits. These bits set the SCI character length from to eight bits. Characters of less than eight bits
                                are right-justified in SCIXBUF and SCIXEMU and are filled with leading 0s in SCIRXBUF. SCITXBUF is not filled with leading 0s. 
                                Table 4-4 lists the bits values and character lengths for SCI CHAR2-0 bits.

		---------------------------------------------------------------
                        SCI CHAR2-0 Bit Values
		------------------------------------
		  SCI CHAR2   SCI CHAR1  SCI CHAR0    Character Length (Bits)
		---------------------------------------------------------------
            0           0          0                 1
            0           0          1                 2
            0           1          0                 3
            0           1          1                 4
            1           0          0                 5
            1           0          1                 6
            1           1          0                 7
            1           1          1                 8
        ---------------------------------------------------------------
*/
#define		SCI_CNTL1		(int *)0x7051			/* SCI Baud rate control */
/*
	XXXX XXXX X000 0000
	15-7:RESERVED  \\ Reads are inderminate and writes have no effect

	6(RW):RX ERR INT ENA  \\ SCI receiver enable. Setting this bit enables an interrupt if the RXERROR bit(SCIRXST.7) becomes set because of errors.
                                 This interrupt capability is provided for error detection when the SCI is serviced by the DMAC

		0 = Receive error interrupt is disabled
		1 = Receive error interrupt is enabled

	5(RW):SW RESET  \\ SCI software reset(active low). Writing a 0 to this bit initializes the SCI state machines and operating flags(SCICT2 and SCIRXST)
                           to the reset condition.
                           The SW RESET bit does nat affected any of the configuration bits and does not change the state of the CLOCK ENA bit, bit4.
			   All affected logic is held in the specified reset atate until a 1 is written to SW RESET (the bit values following a reset are shown
                           beneath each register diagram in this section). Thus, after a system reset, reenable the SCI by writing a 1 to this bit.
 			   Clear this bit after a receiver break detect (BRKD flag, bit SCIRXST.5).
		           SW RESET affects the operating flags of the SCI, but it neither affects the configuration bits nor restores the reset values.
                           Table4-5 lists the affected flags.
                           Once SW RESET is asserted, the flags are frozen until the bits is deasserted.
-------------------------------------------------------------------------------------------------------
   *^.^*   Note: DO Not Change Configuration when SW RESET bit=1
                 The SCI configuration must not be set or altered unless the SW RESET bit is cleared.
                 Set up all Configuration registers before setting SW RESET
                 Otherwise, behavior may be unpredictable
-------------------------------------------------------------------------------------------------------

        * Table 4-5. SW RESET Affected Flags
	------------------------------------------------------------------
	  SCI Flag          Register.Bit            Value After SW RESET
	------------------------------------------------------------------
	   TXRDY              SCICTL2.7                       1
	   TX EMPTY           SCICTL2.6                       1
	   RXWAKE             SCIRXST.1                       0
	   PE                 SCIRXST.2                       0
	   TXRDY              SCIRXST.3                       0
	   TXRDY              SCIRXST.4                       0
	   TXRDY              SCIRXST.5                       0
	   TXRDY              SCIRXST.6                       0
	   TXRDY              SCIRXST.7                       0
	------------------------------------------------------------------

	4(RW):CLOCK ENA  \\ SCI internal clock enable. This bit determines the source of the module clock on the SCICLK pin

		0 = Disable internal clock
		1 = Enable internal clock

	3(RS):TXWAKE  \\ SCI transmitter wakeup method select. The TXWAKE bit controls selection of the data-transmit feature,
                         depending on which transmi mode(idle  line or address bit) is specified at the ADDR/IDLE MODE bit (SCICCR.3)

		0 = Transmit feature is not selected
		1=  Transmit feature selected is dependent on the mode:idle-line or address-bit:

			Idle-line mode : write a 1 to TXWAKE, then write data to register SCITXBUF to generat an idle period of 11 data bits
			Address-bit mode : write a 1 to TXWAKE, then write data to SCITXBUF to set the address bit for that frame to 1

              TXWAKE is not cleared by the SW RESET bit(SCICTL1.5). this bit is only cleared by a system reset or by the transfer of TXWAKE
              to the WUT flag

	2(RW):SLEEP  \\ SCI sleep. In a multiprocessor configuration , this bit controls the receive sleep function. Clearing this bit brings
                        the SCI out of the sleep mode. This configuration and process are further explained in section4.3

		0 = Sleep mode is disabled
		1=  Sleep mode is enabled

		The receiver still operates when the SLEEP bit is set; However, operation does not update the receive buffer ready bit(SCIRXST.6,RXRDY)
                or the error status bits(SCIRXST.5-2:BRKDT,FE,OE, and PE)unless the address byte is detected.
                This bit is not cleared when the address byte is detected.

	1(RW):TXENA  \\ SCI transmitter enable. Data is tansmitted through the SCITXD pin only when TXENA is set, transmission is halted but only after all
                        data previously written to SCITXBUF has been sent

		0 = Transmitter is disabled
		1=  Transmitter is enabled

	0(RW):RXENA  \\ SCI receiver enable. Data is received on the SCIRXD pin and is sent to the receive shift register and then the receive buffers.
                        Thisbit enables or disables the receiver(transfer to the buffers)

		0 = Prevent received characters from transfer into SCIRXEMU and SCIRXBUF receive buffers
		1 = Send receive characters into SCIRXEMU and SCIRXBUF

        Clearing RXENA stops received charaters from being traferred into the two receive buffers and also stops the generation of receiver interrupts 
        However, the receiver shift registercan continue to assemble characters. Thus, if RXENA is set during the reception of a character is transffered 
        into the receive buffer registers, SCIRXEMU and SCIXBUF.  
*/


#define		SCI_HBAUD		(int *)0x7052			/* SCI Baud rate control */
/*
	0000 0000 XXXX XXXX
	15-8(RW):BAUD15-8
*/
#define		SCI_LBAUD		(int *)0x7053			/* SCI Control Reg 1 */
/*
	XXXX XXXX 0000 0000
	7-0(RW):BAUD7-0

	Bits 15-0(RW):  \\ SCI 16-bit baud selection. SCIHBAUD (MSbyte) and SCIBAUD (LSbyte) concatenate to form a 16-bit baud value
                           The internally-generated serial clock is determined by the SYSCLK and the teo baud select registers. 
                           The SCI uses the 16-bit value of these registers to select one 64K serial clock rates for the communication
                           modes
			   The SCI baud rate for the different communication modes is determined in the following ways.
                           
                           @ For BRP  = 1 to 65535
                        ---------------------------------------------------
                                  	      
                                                         SYSCLK  
                             SCI asynchronous baud = ---------------
                                                       (BRP + 1)*8 


                                             SYSCLK 
                             BRP = ----------------------------  -  1
                                     SCI asynchronous baud * 8  


                           @ For BRP  = 0
                        ---------------------------------------------
                                  	      
                                                       SYSCLK  
                             SCI asynchronous baud = -----------
                                                         16 

			BRP where : = 16-bit value in the baud-select registers
*/
#define		SCI_CNTL2		(int *)0x7054			/* SCI Control Reg 2 */
/*
	XXXX XXXX 11XX XX00
	7(R):TXRDY  \\ Transmitter buffer-register ready flag. When set , this bit indicates that the transmit buffer register, SCIXBUF, is ready to receive another character.
                       Writing data to SCITXBUF automatically clears this bit. When set, this flag asserts a transmitter interrupt request if the interrupt-enable bit 
                       TX INT ENA(SCICTL2.0) is also set. TXRDY is set to 1 by enabling the SW RESET bit(SCICTL.2) or by a system reset
		
		0 = SCITXBUF is full
		1 = SCITXBUF is ready to receive the next character 
    
	6(R):TX EMPTY  \\ Transmitter empty flag.

		0 = Transmitter buffer or shift register or both are loaded with data
		1 = Transmitter buffer and shift register are both empty 
 
	5-2:RESERVED  \\ Reads are inderminate and writes have no effect

 	1(RW):RX/BK INT ENA  \\ Receive-buffer/break interrupt enable

		0 = Disable RXRDY/BRKDT interrupt
		1 = Enable RXRDY/BRKDT interrupt

	0(RW):TX INT ENA  \\ SCITBUF-interrupt enable

		0 = Disable TXRDY interrupt
		1 = Enable TXRDY interrupt
*/
#define		SCI_RX_STAT		(int *)0x7055			/* SCI Receive status reg */
/*
	XXXX XXXX 0000 000X
	7(R):RX ERROR  \\ SCI receiver-error flag

		0 = No error flags are set
		1 = Error flags are set 
 
	6(R):RXRDY  \\ SCI receiver-ready flag

		0 = No new character in SCIRXBUF
		1 = Character ready to be read from SCIRXBUF 
  
	5(R):BRKDT  \\ SCI break-detect flag

		0 = No break condition 
		1 = Break condition occurred  
 
	4(R):FE  \\ SCI framing-error flag

		0 = No framing error is detected 
		1 = Framing error is detected  
 
	3(R):OE  \\ SCI overrun-error flag

		0 = No overrun error is detected 
		1 = Overrun error is detected  
 
	2(R):PE  \\ SCI parity-error flag

		0 = No parity error or parity is disabled 
		1 = Parity error is detected  
 
	1(R):RXWAKE  \\ Receiver wakeup-detect flag

                        A value of 1 in this bit indicates detection of a receiver wakeup condition.
                         
	0:RESERVED  \\ Reads are indeterminate and writes have no effect 
*/
#define		SCI_RX_EMU		(int *)0x7056			/* SCI EMU data buffer */
/*
	XXXX XXXX XXXX XXXX
        7-0(R):ERXDT7-0  \\ When the current data received is shifted to the receive buffer, 
                            flag bit RXRDY is set and the data i ready to be read. If the RX/BK INT ENA bit(SCICTL2.1)
                            is set, this shift also causes an interrupt. When SCIRXBUF is read, the RXRDY flag is reset.
                            SCIRXBUF is cleared by a system reset. 
*/
#define		SCI_RX_BUF		(int *)0x7057			/* SCI Receive data buffer */
/*
	XXXX XXXX XXXX XXXX
        7-0(R):RXDT7-0  \\ Data bits to be transmitted are written to the transmit data buffer register(SCITXBUF). The transfer of data
                           from this register to the TXSHF transmitter  shift register sets the TXRDY flag(SCICTL2.7), 
                           indicating that SCITCBUF is ready to receive another set of data. If bit TX INT ENA(SCICTL2.0)is set, 
                           this data transfer also causes an interrup. These bits must be right justified because the left-most bits are   
                           ignored for characters less than eight bits long. 
*/
#define		SCI_TX_BUF		(int *)0x7059			/* SCI Transmit data buffer */
/*
	XXXX XXXX 0000 0000
        7-0(RW):TXDT7-0
*/
#define		SCI_PORT_C1		(int *)0x705D			/* SCI Port control reg1 */
#define		SCI_PORT_C2		(int *)0x705E			/* SCI Port control reg2 */
/*
	XXXX XXXX X000 X000
        7(R):SCITXD DATA IN  \\ Contains the current value of pin SCITXD

		0 = Pin SCITXD value as 0	
		1 = Pin SCITXD value as 1
		 
	6(RW):SCITXD DATA OUT  \\ Value to be ooutput on pin SCITXD. This bit contains the data 
                                  to be output on the SCITXD if it is a general-purpose digital-I/O output pin
                                  For this configuration, clear bit SCIPC2.5 to 0 and set bit SCIPC2.4 to 1 

	5(RW):SCITXD FUNCTION  \\ Defines the function of pin SCITXD

		0 = SCITXD is a general-purpose digital I/O pin 	
		1 = SCITXD is a the SCI transmit pin 
		 
	4(RW):SCITXD DATA DIR  \\ Defines the data direction of pin SCITXD

		0 = SCITXD is a digital input pin  	
		1 = SCITXD is a digital output pin 
		 
        3(R):SCIRXD DATA IN  \\ Contains the current value of pin SCIRXD

		0 = Pin SCIRXD value as 0
		1 = Pin SCIRTXD value as 1
		 
	2(RW):SCIRXD DATA OUT  \\ Value to be ooutput on pin SCIRXD.

                0 = A 0 value output on pin SCIRXD 	
		1 = A 1 value output on pin SCIRXD
		
	1(RW):SCIRXD FUNCTION  \\ Defines the function of pin SCIRXD

		0 = SCIRXD is a general-purpose digital I/O pin 	
		1 = SCIRXD is a the SCI receive pin 
		 
	0(RW):SCIRXD DATA DIR  \\ Defines the data direction of pin SCIRXD

		0 = SCIRXD is a digital input pin  	
		1 = SCIRXD is a digital output pin 
*/
#define		SCI_PRI 		(int *)0x705F			/* SCI Priority control reg */
/*
	XXXX XXXX X000 XXXX
        7:RESERVED  \\ Reads are indeterminate and writes have no effect

	6(RW):SCITX PRIORITY  \\ SCI transmitter interrupt priority select

		0 = Interrupts are high-priority requests 	
		1 = Interrupts are low-priority requests 	  
		   
	5(RW):SCIRX PRIORITY  \\ SCI receiver interrupt priority select

		0 = Interrupts are high-priority requests 	
		1 = Interrupts are low-priority requests 	  
		    
	4(RW):SCI ESPEN  \\ SCI emulator suspend enable

\\ SCI transmitter interrupt priority select

		0 = When the suspended signal goes high, the SCI continues operation 
                    until the curent transmit and receive functions are complete  	
		1 = When the suspended signal goes high, the SCI state machine is frozen 	  
		    
	3-0:RESERVED  \\ Reads are indeterminate and writes have no effect
*/


/* Event Manager (EV) - EV Base Address = 0x7400 */

 
#define		GPTCON	   	(int *)0x7400  		/* General Timer Controls */
/*
	1110 0000 0000 0000
        15(R):T3STAT  \\ GP timer 3 status. Read only

		0 = Count down
		1 = Count up
		 
	14(R):T2STAT  \\ GP timer 2 status. Read only
		
		0 = Count down
		1 = Count up
		 
	13(R):T1STAT  \\ GP timer 1 status. Read only
		
		0 = Count down
		1 = Count up

	12-11(RW):T3TOADC  \\ Start ADC by GP timer 3 event
		
		00 = No event starts ADC
		01 = Setting of underflow interrupt flag
		10 = Setting of period interrupt flag
		11 = Setting of compare interrupt flag

	10-9(RW):T2TOADC  \\ Start ADC by GP timer 2 event
		
		00 = No event starts ADC
		01 = Setting of underflow interrupt flag. starts ADC
		10 = Setting of period interrupt flag. starts ADC
		11 = Setting of compare interrupt flag. starts ADC

	8-7(RW):T1TOADC  \\ Start ADC by GP timer 1event
		
		00 = No event starts ADC
		01 = Setting of underflow interrupt flag
		10 = Setting of period interrupt flag
		11 = Setting of compare interrupt flag

        6(RW):TCOMPOE  \\ Compare output enable. Active PDPINT writers zero to this bit.

		0 = Disable all three GP timer compare outputs (all three compare outputs are 
  		    put in high-impedance state)
		1 = Enable all three GP timer compare outputs.
  
	5-4(RW):T3PIN  \\ Polarity of GP timer 3 compare output

		00 = Foced low
		01 = Active low
		10 = Active high
		11 = Forced high

	3-2(RW):T2PIN  \\ Polarity of GP timer 2 compare output

		00 = Foced low
		01 = Active low
		10 = Active high
		11 = Forced high

	1-0(RW):T1PIN  \\ Polarity of GP timer 1 compare output

		00 = Foced low
		01 = Active low
		10 = Active high
		11 = Forced high

*/
#define		T1CNT	   	(int *)0x7401  		/* T1 Counter Register */
#define		T1CMP	   	(int *)0x7402  		/* T1 Compare Register */
#define		T1PER	   	(int *)0x7403   		/* T1 Period Register */
#define		T1CON	   	(int *)0x7404   		/* T1 Control Register */
/*
	0000 0000 0000 0000
        15(RW):FREE 14(RW):SOFT 13-11(RW):TMODE2-0 10-8(RW):TPS2-0 
        7(RW):TSWT1  6(RW):TENABLE 5-4(RW):TCLKS1-0 3-2(RW):TCLD1-0 1(RW):TECMPR 0(RW):SELT1PR

*/
#define		T2CNT	   	(int *)0x7405  		        /* T2 Counter Register */
#define		T2CMP	   	(int *)0x7406   		/* T2 Compare Register */
#define		T2PER	   	(int *)0x7407   		/* T2 Period Register */
#define		T2CON	   	(int *)0x7408   		/* T2 Control Register */
/*
	0000 0000 0000 0000
        15(RW):FREE 14(RW):SOFT	 \\ Emulation control bits
	    
                00 = Stop immediately on emulation suspend
                01 = Stop after current timer period is completed on emulation suspend
                10 = Operation is not affected by emulation suspend
                11 = Operation is not affected by emulation suspend    	  
		
        13-11(RW):TMODE2-0  \\ Count mode selection
		
		000 = Stop/hold
		001 = Single up counting mode 
		010 = Continuous up counting mode
		011 = Directional up/down counting mode
		100 = Single up/down counting mode
		101 = Continuous up/down counting mode
		110 = Reserved. Result is unpredictable
		111 = Reserved. Result is unpredictable

	10-8(RW):TPS2-0  \\ Input clock pescaler
		
		000 = x/1 
		001 = x/2
		010 = x/4
		011 = x/8
		100 = x/16
		101 = x/32
		110 = x/64
		111 = x/128           x = CPU clock frequency
 
        7(RW):TSWT1  \\ (GP timer start with GP timer 1). start timer with GP timer 1 timer enable bit. This bit is reserved in T1CON.
		
		0 = Use own TENABLE bit
		1 = Use TENABLE bit of T1CON to enable and disable operation ignoring own TENABLE bit
   
	6(RW):TENABLE  \\ Timer enable. In single up counting and single up/down counting modes, 
                          this bit is cleared to 0 by the timer aafter it completes a period of operation.
		
		0 = Disable timer operation; that is, put the timer in hold and reset the prescaler counter.
		1 = Enable timer operations.
   
	5-4(RW):TCLKS1-0  \\ Clock source select.

		00 = Internal
		01 = External
		10 = Rollover from GP timer2. (Only applicable to T3CON when GP timers 2 and 3 are cascaded into a 32-bit timer;
                     reserved in T1CON and T2CON; ILLEGAL if SELT1PR is 1)
		11 = Quadrature encoder pulse circuit. (Only applicable to T2CON and T3CON;  
	             reserved in T1CON; ILLEGAL if SELT1PR is 1)

                     ILLEGAL means result is unpredicable.
    
        3-2(RW):TCLD1-0  \\ Timer compare (active)register reload condition
		
		00 = When counter is 0
		01 = When counter value is 0 or equals period register value
		10 = Immediately
		11 = Reserved
  
	1(RW):TECMPR  \\ Timer compare enable
	
		0 = Disable timer compare operation 
		1 = Enable timer compare operation 
		
	0(RW):SELT1PR  \\ Period register select. This bit is reserved in T1CON.

		0 = Use own period register
		1 = Use T1PR as period register ignoring own period register

-----------------------------------------------------------------------------------------------------------------
    *^.^*   Note: Synchronization of the GP Timers
                  Two consecutive writes to T1CON are   required to ensure the synchronization of the GP Timers
                  when GP timers T1CON[6] is used to enable GP timer 2 or 3:
                    1) Configure all other bits with T1CON[6] set to 0
	            2) Enable GP timer 1 and, thus, GP timer 2 or GP timers 2 or 3, by setting T1CON[6] to 1. 	                 
-----------------------------------------------------------------------------------------------------------------
*/

#define		T3CNT	   	(int *)0x7409   		/* T3 Counter Register */
#define		T3CMP	   	(int *)0x740A   		/* T3 Compare Register */
#define		T3PER	   	(int *)0x740B   		/* T3 Period Register */
#define		T3CON	   	(int *)0x740C   		/* T3 Control Register */
/*
	0000 0000 0000 0000
        15(RW):TREE 14(RW):SOFT 13-11(RW):TMODE2-0 10-8(RW):TPS2-0 
        7(RW):TSWT1  6(RW):TENABLE 5-4(RW):TCLKS1-0 3-2(RW):TCLD1-0 1(RW):TECMPR 0(RW):SELT1PR
*/
#define		COMCON	   	(int *)0x7411   		/* Compare Unit Control */
/*
	0000 0000 0000 0000
        15(RW):CENABLE  \\ Full compare enable
		
		0 = Disable full compare operation. All shadowed registers (CMPRx, SCMPRx, ACTR, SACTR)
                    become transparent
		1 = Enable compare operation.
 
	14-13(RW):CLD1-0  \\ Full compare register CMPRx reload condition
		
		00 = When T1CNT = 0 (that is, underflow)
		01 = When T1CNT = 0 or T1CNT=T1PR (that is, underflow or period match) 
		10 = Immediately
		11 = Reserved. Result is unpredictable
 
	12(RW):SVENABLE  \\ Space vector PWM mode enable. In space vector PWM mode, all six full compare outputs are PWM outputs.
                            SAENABLE\1 overrides COMCON bits 0, 1, and 2.
    
		0 = Disable space vector PWM mode.
		1 = Enable space vector PWM mode.

	11-10(RW):ACTRLD1-0  \\ Full compare action register ACTR reload condition

		00 = When T1CNT=0 (that is, on underflow)
		01 = When T1CNT = 0 or T1CNT=T1PR (that is, underflow or period match) 
		10 = Immediately
		11 = Reserved. Result is unpredictable
    
	9(RW):FCOMPOE  \\ Full compare output enable. Active PDPINT clears this bit to 0
		
		0 = Full compare output pins are in high-impedance state; they are disabled.
		1 = Full compare output pins are not in high-impedance state; they are enabled.

	8(RW):SCOMPOE  \\ Simple compare output enable. Active PDPINT cleares this bit to 0

		0 = Simple compare output pins are in high-impedance state; they are disabled.
		1 = Simple compare output pins are not in high-impedance state; they are enabled.

        7(RW):SELTMR  \\ Simple compare time base select

		0 = GP timer 1
		1 = GP timer 2 
 
	6-5(RW):SCLD1-0  \\ Simple compare register SCMPRx reload condition
		
		00 = When TyCNT=0 (y=1 or 2 according to SELTMR)
		01 = When TyCNT=0 or TyCNT=TyPR
		10 = Immediately
		11 = Reserved. 
    
	4-3(RW):SACTRLD1-0  \\ Simple compare action register SACTR reload condition
		
		00 = When TyCNT=0 (y=1 or 2 according to SELTMR)
		01 = When TyCNT=0 or TyCNT=TyPR
		10 = Immediately
		11 = Reserved. 
     
	2(RW):SELCMP3  \\ Mode select for PWM6/CMP6 and PWM5/CMP5(for full compare unit3)

		0 = Compare mode
		1 = PWM mode 

        1(RW):SELCMP2  \\ Mode select for PWM4/CMP4and PWM3/CMP3(for full compare unit2)

		0 = Compare mode
		1 = PWM mode 

	0(RW):SELCMP1  \\ Mode select for PWM2/CMP2 and PWM1/CMP1(for full compare unit1)

		0 = Compare mode
		1 = PWM mode 
------------------------------------------------------------------------------------------------------------
   *^.^*   Note: Two consecutive writes to COMCON are required to ensure the proper operation of the full
                 compare units in PWM mode:
                   1) Enable PWM mode without enabling compare operation 
                   2) Enable compare operation by setting COMCON[15] to 1 without changing any other bits. 	                 
------------------------------------------------------------------------------------------------------------
*/
#define		ACTR	   	(int *)0x7413   		/* Compare Unit Output Action Control */
/*
	0000 0000 0000 0000
        15(RW):SVRDIR  \\ Space vector PWM rotation direction. Used only in space vector PWM output generation 

		0 = Positive (CCM)
		1 = Negative (CW)

	14-12(RW):D2-0  \\ Basic space vector bits. Used only in space vector PWM output generation
 
	11-10(RW):CMP6ACT1-0  \\ Action on full compare output pin 6, PWM6/CMP6
                      
		-----------------------------------------------------
		   Bits 11-10        Compare Mode      PWM Mode  
		-----------------------------------------------------
			00                 Hold          Forced low
			01                 Reset         Active low
			10                 Set           Active high
			11                 Toggle        Forced high                      
		-----------------------------------------------------
          
	9-8(RW):CMP5ACT1-0  \\ Action on full compare output pin 5, PWM5/CMP5 

		-----------------------------------------------------
		   Bits 9-8          Compare Mode      PWM Mode  
		-----------------------------------------------------
			00                 Hold          Forced low
			01                 Reset         Active low
			10                 Set           Active high
			11                 Toggle        Forced high
              	-----------------------------------------------------
          
        7-6(RW):CMP4ACT1-0  \\ Action on full compare output pin 4, PWM4/CMP4 

		-----------------------------------------------------
		   Bits 7-6          Compare Mode      PWM Mode  
		-----------------------------------------------------
			00                 Hold          Forced low
			01                 Reset         Active low
			10                 Set           Active high
			11                 Toggle        Forced high
       	-----------------------------------------------------
            
	5-4(RW):CMP3ACT1-0  \\ Action on full compare output pin 3, PWM3/CMP3 

		-----------------------------------------------------
		   Bits 5-4          Compare Mode      PWM Mode  
		-----------------------------------------------------
			00                 Hold          Forced low
			01                 Reset         Active low
			10                 Set           Active high
			11                 Toggle        Forced high
       	-----------------------------------------------------
          
	3-2(RW):CMP2ACT1-0  \\ Action on full compare output pin 2, PWM2/CMP2 

		-----------------------------------------------------
		   Bits 3-2          Compare Mode      PWM Mode  
		-----------------------------------------------------
			00                 Hold          Forced low
			01                 Reset         Active low
			10                 Set           Active high
			11                 Toggle        Forced high
      	-----------------------------------------------------
          
	1-0(RW):CMP1ACT1-0  \\ Action on full compare output pin 1, PWM1/CMP1 

		-----------------------------------------------------
		   Bits 1-0          Compare Mode      PWM Mode  
		-----------------------------------------------------
			00                 Hold          Forced low
			01                 Reset         Active low
			10                 Set           Active high
			11                 Toggle        Forced high
       	-----------------------------------------------------
          
*/
#define		SACTR	   	(int *)0x7414   		/* S Comp Unit Output Action Control */
/*
	XXXX XXXX XX00 0000
        15-6:RESERVED  \\ Reads are 0 and writes have no effect
 
	5-4(RW):SCMP3ACT1-0  \\ Action on simple compare output pin 3, PWM9/CMP9
		      
		00 = Forced low
                01 = Active low
		10 = Active high
                11 = Forced high
 
	3-2(RW):SCMP2ACT1-0  \\ Action on simple compare output pin 2, PWM8/CMP8
		    
                00 = Forced low
                01 = Active low
		10 = Active high
                11 = Forced high
 
	1-0(RW):SCMP1ACT1-0  \\ Action on simple compare output pin 1, PWM7/CMP7
		      
                00 = Forced low
                01 = Active low
		10 = Active high
                11 = Forced high
*/
#define		DBTCON	   	(int *)0x7415   		/* Dead Band Timer Control */
/*
	0000 0000 0000 0XXX
        15-8(RW):DBT7-0  \\ Dead-band timer period. These bits define the period value of the three 8-bit dead-band timers 

	7(RW):EDBT3  \\ Dead-band timer 3 enable (for pins PWM5/CMP5 and PWM6/CMP6 of full compare unit 3)
		
		0 = Disable
		1 = Enable  

	6(RW):EDBT2  \\ Dead-band timer 2 enable (for pins PWM3/CMP3 and PWM4/CMP4 of full compare unit 3)
		
		0 = Disable
		1 = Enable  

	5(RW):EDBT1  \\ Dead-band timer 1 enable (for pins PWM1/CMP1 and PWM2/CMP2 of full compare unit 3)
		
		0 = Disable
		1 = Enable  
	
	4-3(RW):DBTPS1-0  \\ Dead-band timer prescaler

                00 = x/1
                01 = x/2
		10 = x/4
                11 = x/8            where x=CPU clock frequency 
			            
	2-0:RESERVED  \\ Reads are 0 and writes have no effect 
*/
#define		CMPR1	   	(int *)0x7417   		/* Compare Channel 1 Threshold */
#define		CMPR2	   	(int *)0x7418  		/* Compare Channel 2 Threshold */
#define		CMPR3	   	(int *)0x7419   		/* Compare Channel 3 Threshold */
#define		SCMPR1	   	(int *)0x741A  		/* S Comp Channel 1 Threshold */
#define		SCMPR2	   	(int *)0x741B  		/* S Comp Channel 2 Threshold */
#define		SCMPR3	   	(int *)0x741C   		/* S Comp Channel 3 Threshold */
#define		CAPCON	   	(int *)0x7420   		/* Capture Unit Control */
/*
	0000 0000 0000 0000
        15(RW):CAPRES  \\ Capture reset
                          This is a write only bit. Any read operation of this bit results in zero. 
                          Writing zero to Bit 15 clears all the capture and QED registers. 
                          However, you do not need to write 1 to Bit 15 in order to enable the capture function

		0 = Clear all registers of capture units and QEP circuit to 0
		1 = No action
   
	14-13(RW):CAPQEPN  \\ Capture units 1 and 2 QEP circuit control

		00 = Disable capture units 1 and 2, and QEP circuit. The FIFO stacks retain their contents. 
		01 = Enable capture units 1 and 2. Disable QEP circuit
		10 = Reserved
		11 = Enable QEP circuit. Disable capture units 1 and 2. Bits4-7 and 9 are ignored

	12(RW):CAP3EN  \\ Capture unit 3 control

		0 = Disable capture unit 3. FIFO stack of capture unit 3 retains its contents. 
		1 = Enable capture unit 3
		
	11(RW):CAP4EN  \\ Capture unit 4 control

		0 = Disable capture unit 4. FIFO stack of capture unit 4 retains its contents. 
		1 = Enable capture unit 4
		
	10(RW):CAP34TSEL  \\ GP timer selection for capture units 3 and 4

		0 = Select GP timer 2 
		1 = Select GP timer 3
		 
	9(RW):CAP12TSEL  \\ GP timer selection for capture units 1 and 1

		0 = Select GP timer 2 
		1 = Select GP timer 3
		 
	8(RW):CAP4TOADC  \\ Capture unit 4 event starts ADC
		
		0 = No action
		1 = Start ADC when the CAP4INT flag is set

        7-6(RW):CA1EDGE  \\ Edge detection contol for capture unit 1
		
		00 = No detection 
		01 = Dection rising edge 
 		10 = Dection falling edge 
		01 = Dection both edge 
 
	5-4(RW):CAP2EDGE  \\ Edge detection contol for capture unit 2
		
		00 = No detection 
		01 = Dection rising edge 
 		10 = Dection falling edge 
		01 = Dection both edge 
 
	3-2(RW):CAP3EDGE  \\ Edge detection contol for capture unit 3
		
		00 = No detection 
		01 = Dection rising edge 
 		10 = Dection falling edge 
		01 = Dection both edge 
 
	1-0(RW):CAP4EDGE  \\ Edge detection contol for capture unit 4
		
		00 = No detection 
		01 = Dection rising edge 
 		10 = Dection falling edge 
		01 = Dection both edge 
 
*/
#define		CAPFIFO    	(int *)0x7422   		/* FIFO1-4 Status Register */
/*
	0000 0000 0000 0000
        15-14(R):CAP4FIFO  \\ Status. Read only
		
		00 = Empty
		01 = Has one entry
		10 = Has two entries
		11 = Had two entries and captured another one; first entry has been lost
  
	13-12(R):CAP3FIFO  \\ Status. Read only
		
		00 = Empty
		01 = Has one entry
		10 = Has two entries
		11 = Had two entries and captured another one; first entry has been lost
  
	11-10(R):CAP2FIFO  \\ Status. Read only
		
		00 = Empty
		01 = Has one entry
		10 = Has two entries
		11 = Had two entries and captured another one; first entry has been lost
   
	9-8(R):CAP1FIFO  \\ Status. Read only
		
		00 = Empty
		01 = Has one entry
		10 = Has two entries
		11 = Had two entries and captured another one; first entry has been lost
  
        7(W):CAPFIFO15  \\ Bit 15 clear. Write only

		0 = Do nothing
		1 = Clear bit 15

	6(W):CAPFIFO14  \\ Bit 14 clear. Write only

		0 = Do nothing
		1 = Clear bit 14

	5(W):CAPFIFO13  \\ Bit 13 clear. Write only

		0 = Do nothing
		1 = Clear bit 13

	4(W):CAPFIFO12  \\ Bit 12 clear. Write only

		0 = Do nothing
		1 = Clear bit 12

	3(W):CAPFIFO11  \\ Bit 11 clear. Write only

		0 = Do nothing
		1 = Clear bit 11

	2(W):CAPFIFO10  \\ Bit 10 clear. Write only

		0 = Do nothing
		1 = Clear bit 10

	1(W):CAPFIFO9  \\ Bit 9 clear. Write only

		0 = Do nothing
		1 = Clear bit 9

	0(W):CAPFIFO8  \\ Bit 8 clear. Write only
		0 = Do nothing
		1 = Clear bit 8
*/
#define		FIFO1	   	(int *)0x7423   		/* Capture Channel 1 FIFO Top */
#define		FIFO2	   	(int *)0x7424  		/* Capture Channel 2 FIFO Top */
#define		FIFO3	   	(int *)0x7425   		/* Capture Channel 3 FIFO Top */
#define		FIFO4	   	(int *)0x7426   		/* Capture Channel 4 FIFO Top */
#define		IMRA	   	(int *)0x742C   		/* Group A Interrupt Mask Register */
/*
	XXXX X000 0000
	15-11:RESERVED  \\ Reads are 0 and writes have no effect
	
	10(RW):T1OFINT ENABLE

		0 = Disable
		1 = Enable
 
	9(RW):T1UFINT ENABLE

		0 = Disable
		1 = Enable
  
	8(RW):T1CINT ENABLE

		0 = Disable
		1 = Enable
  
       7(RW):T1PINT ENABLE 
       
		0 = Disable
		1 = Enable
 
       6(RW):SCMP3INT ENABLE

		0 = Disable
		1 = Enable
  
       5(RW):SCMP2INT ENABLE

		0 = Disable
		1 = Enable
  
       4(RW):SCMP3INT ENABLE

		0 = Disable
		1 = Enable
  
       3(RW):CMP3INT ENABLE

		0 = Disable
		1 = Enable
 
       2(RW):CMP2INT ENABLE

		0 = Disable
		1 = Enable
  
       1(RW):CMP1INT ENABLE

		0 = Disable
		1 = Enable
  
       0(RW):PDPINT ENABLE

		0 = Disable
		1 = Enable
 */
#define		IMRB	   	(int *)0x742D   		/* Group B Interrupt Mask Register */
/*
	XXXX XXXX 0000 0000
        15-8:RESERVED  \\ Reads are 0 and writes have no effect 
	7(RW):T3OFINT ENABLE 

		0 = Disable
		1 = Enable

	6(RW):T3UFINT ENABLE

		0 = Disable
		1 = Enable
 
	5(RW):T3CINT ENABLE

		0 = Disable
		1 = Enable
 
	4(RW):T3PINT ENABLE

		0 = Disable
		1 = Enable
 
        3(RW):T2OFINT ENABLE 

		0 = Disable
		1 = Enable

	2(RW):T2UFINT ENABLE 

		0 = Disable
		1 = Enable

	1(RW):T2CINT ENABLE

		0 = Disable
		1 = Enable
 
	0(RW):T2PINT ENABLE

		0 = Disable
		1 = Enable

*/
#define		IMRC	   	(int *)0x742E   		/* Group C Interrupt Mask Register */
/*
	XXXX XXXX XXXX 0000
        15-4:RESERVED  \\ Reads are 0 and writes have no effect 
 
	3(RW):CAP4INT ENABLE 

		0 = Disable
		1 = Enable

	2(RW):CAP3INT ENABLE 

		0 = Disable
		1 = Enable

	1(RW):CAP2INT ENABLE 

		0 = Disable
		1 = Enable

	0(RW):CAP1INT ENABLE

		0 = Disable
		1 = Enable

*/
#define		IFRA	   	(int *)0x742F   		/* Group A Interrupt Flag Register */
/*
	XXXX X000 0000 0000
        15-11:RESERVED  \\ Reads return 0 and writes have no effect
 
	10(RW):T1OFINT FLAG  \\ GP timer 1 overflow interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	9(RW):T1UFINT  \\ GP timer 1 underflow interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	8(RW):T1CINT   \\ GP timer 1 compare interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
        7(RW):T1PINT   \\ GP timer 1 period interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	6(RW):SCMP3INT  \\ Simple compare 3 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	5(RW):SCMP2INT  \\ Simple compare 2 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	4(RW):SCMP3INT ENABLE  \\ Simple compare 1 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	3(RW):CMP3INT 	\\ Full compare 3 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	2(RW):CMP2INT FLAG  \\ Full compare 2 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	1(RW):CMP1INT  \\ Full compare 1 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	0(RW):PDPINT  \\ Power drive protection interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
*/
#define		IFRB	   	(int *)0x7430  		/* Group B Interrupt Flag Register */
/*
	XXXX XXXX 0000 0000
        15-8:RESERVED  \\ Reads return 0 and writes have no effect 
	
	7(RW):T3OFINT FLAG  \\ GP timer 3 overflow interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	6(RW):T3UFINT  \\ GP timer 3 underflow interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	5(RW):T3CINT  \\ GP timer 3 compare interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	4(RW):T3PINT  \\ GP timer 3 period interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	3(RW):T2OFINT  \\ GP timer 2 overflow interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	2(RW):T2UFINT  \\ GP timer 2 underflow interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	 
	1(RW):T2CINT  \\ GP timer 2compare interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
	0(RW):T2PINT  \\ GP timer 2 period interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	
*/
#define		IFRC	   	(int *)0x7431   		/* Group C Interrupt Flag Register */
/*
	XXXX XXXX XXXX 0000
        15-4:RESERVED  \\ Reads return 0 and writes have no effect 

	3(RW):CAP4INT FLAG  \\ Capture 4 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	   
	2(RW):CAP3INT  \\ Capture 3 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	   
	1(RW):CAP2INT  \\ Capture 2 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	   
	0(RW):CAP1INT  \\ Capture 1 interrupt

		Read:  0 = Flag is reset
		       1 = Flag is set
 	        Write: 0 = No effect
		       1 = Reset flag
	   
*/
#define		IVRA	   	(int *)0x7432   		/* Group A Int. Vector Offset(AD dec only) */
/*
	0000 0000 0000 0000
        15-6(R):0 RESERVED. Reads return 0 and writes have no effect
 
	5-0(R):D5-0  // Vector (ID) of the interrupt flag that hasthe highest priority among the set and unmasked interrupt flags of EVIFRA;
                        0 if no interrupt flag is set and unmasked inEVIFRA
*/
#define		IVRB	   	(int *)0x7433   		/* Group B Int. Vector Offset(AD dec only) */
/*
	0000 0000 0000 0000
        15-6(R):0 RESERVED. Reads return 0 and writes have no effect
 
	5-0(R):D5-0  // Vector (ID) of the interrupt flag that hasthe highest priority among the set and unmasked interrupt flags of EVIFRA;
                        0 if no interrupt flag is set and unmasked inEVIFRA
*/
#define		IVRC	   	(int *)0x7434  		/* Group C Int. Vector Offset(AD dec only) */
/*
	0000 0000 0000 0000
        15-6(R):0 RESERVED. Reads return 0 and writes have no effect
 
	5-0(R):D5-0  // Vector (ID) of the interrupt flag that hasthe highest priority among the set and unmasked interrupt flags of EVIFRA;
                        0 if no interrupt flag is set and unmasked inEVIFRA
*/

#endif
